@@ -6,6 +6,7 @@ use crate::sys::engine as engine_imp;
 pub(crate) use crate::sys::engine::default_engine;
 #[cfg(feature = "sys")]
 use crate::IntoBytes;
+use crate::StoreRef;
 #[cfg(feature = "sys")]
 use shared_buffer::OwnedBuffer;
 #[cfg(feature = "sys")]
@@ -28,6 +29,11 @@ use crate::jsc::engine as engine_imp;
 #[cfg(feature = "jsc")]
 pub(crate) use crate::jsc::engine::default_engine;
 
+#[cfg(feature = "wasm-c-api")]
+use crate::c_api::engine as engine_imp;
+#[cfg(feature = "wasm-c-api")]
+pub(crate) use crate::c_api::engine::default_engine;
+
 /// The engine type
 #[derive(Clone, Debug)]
 pub struct Engine(pub(crate) engine_imp::Engine);
@@ -149,6 +155,11 @@ impl<'a> EngineRef<'a> {
 pub trait AsEngineRef {
     /// Returns a `EngineRef` pointing to the underlying context.
     fn as_engine_ref(&self) -> EngineRef<'_>;
+
+    /// Returns an optional `StoreRef` is the passed reference is a `Store`.
+    fn maybe_as_store(&self) -> Option<StoreRef<'_>> {
+        None
+    }
 }
 
 impl AsEngineRef for EngineRef<'_> {
@@ -167,4 +178,8 @@ where
     fn as_engine_ref(&self) -> EngineRef<'_> {
         (**self).as_engine_ref()
     }
+
+    fn maybe_as_store(&self) -> Option<StoreRef<'_>> {
+        (**self).maybe_as_store()
+    }
 }
