@@ -5,6 +5,8 @@ use std::mem::MaybeUninit;
 use std::ops::Range;
 use wasmer_types::Pages;
 
+#[cfg(feature = "wasm-c-api")]
+use crate::c_api::externals::memory_view as memory_view_impl;
 #[cfg(feature = "js")]
 use crate::js::externals::memory_view as memory_view_impl;
 #[cfg(feature = "jsc")]
@@ -28,7 +30,7 @@ impl<'a> MemoryView<'a> {
 
     /// Returns the pointer to the raw bytes of the `Memory`.
     //
-    // This used by wasmer-emscripten and wasmer-c-api, but should be treated
+    // This used by wasmer-c-api, but should be treated
     // as deprecated and not used in future code.
     #[doc(hidden)]
     pub fn data_ptr(&self) -> *mut u8 {
