@@ -12,6 +12,12 @@ pub(crate) use crate::jsc::vm::{
     VMFuncRef, VMFunctionCallback, VMFunctionEnvironment, VMInstance, VMTrampoline,
 };
 
+#[cfg(feature = "wasm-c-api")]
+pub(crate) use crate::c_api::vm::{
+    VMExtern, VMExternFunction, VMExternGlobal, VMExternMemory, VMExternRef, VMExternTable,
+    VMFuncRef, VMFunctionCallback, VMFunctionEnvironment, VMInstance, VMTrampoline,
+};
+
 #[cfg(feature = "sys")]
 pub(crate) use crate::sys::vm::{
     VMExtern, VMExternFunction, VMExternGlobal, VMExternMemory, VMExternRef, VMExternTable,
@@ -27,6 +33,9 @@ pub use wasmer_vm::{VMConfig, VMFunction, VMGlobal, VMMemory, VMSharedMemory, VM
 #[cfg(feature = "jsc")]
 pub use crate::jsc::vm::{VMFunction, VMGlobal, VMMemory, VMSharedMemory, VMTable};
 
+#[cfg(feature = "wasm-c-api")]
+pub use crate::c_api::vm::{VMFunction, VMGlobal, VMMemory, VMSharedMemory, VMTable};
+
 // Needed for tunables customization (those are public types now)
 #[cfg(feature = "sys")]
 pub use wasmer_vm::{
