@@ -29,6 +29,10 @@ fn global_new() -> Result<(), String> {
 }
 
 #[universal_test]
+#[cfg_attr(
+    feature = "wamr",
+    ignore = "wamr does not support globals unattached to instances"
+)]
 fn global_get() -> Result<(), String> {
     let mut store = Store::default();
 
@@ -56,6 +60,10 @@ fn global_get() -> Result<(), String> {
 }
 
 #[universal_test]
+#[cfg_attr(
+    feature = "wamr",
+    ignore = "wamr does not support globals unattached to instances"
+)]
 fn global_set() -> Result<(), String> {
     let mut store = Store::default();
     let global_i32 = Global::new(&mut store, Value::I32(10));
@@ -76,6 +84,7 @@ fn global_set() -> Result<(), String> {
 }
 
 #[universal_test]
+#[cfg_attr(feature = "wasmi", ignore = "wasmi does not support funcrefs")]
 fn table_new() -> Result<(), String> {
     let mut store = Store::default();
     let table_type = TableType {
@@ -124,6 +133,77 @@ fn table_get() -> Result<(), String> {
 #[universal_test]
 fn table_set() -> Result<(), String> {
     // Table set not yet tested
+    #[cfg(feature = "sys")]
+    {
+        let mut store = Store::default();
+
+        let table_type = TableType {
+            ty: Type::ExternRef,
+            minimum: 1,
+            maximum: None,
+        };
+        let extern_ref = ExternRef::new(&mut store, 0u32);
+        let table = Table::new(
+            &mut store,
+            table_type,
+            Value::ExternRef(Some(extern_ref.clone())),
+        )
+        .map_err(|e| format!("{e:?}"))?;
+        assert_eq!(table.ty(&store), table_type);
+
+        let v = table.get(&mut store, 0);
+        assert!(v.is_some());
+
+        let v = v.unwrap();
+
+        let v = if let Value::ExternRef(Some(ext)) = v {
+            ext.downcast::<u32>(&mut store)
+        } else {
+            return Err("table.get does not match `ExternRef(Some(..))`!".into());
+        };
+
+        let v = v.unwrap();
+        assert_eq!(*v, 0u32);
+
+        let extern_ref = ExternRef::new(&mut store, 1u32);
+        table
+            .set(&mut store, 0, Value::ExternRef(Some(extern_ref)))
+            .map_err(|e| e.to_string())?;
+
+        let v = table.get(&mut store, 0);
+        assert!(v.is_some());
+        let v = v.unwrap();
+
+        let v = if let Value::ExternRef(Some(ext)) = v {
+            ext.downcast::<u32>(&mut store)
+        } else {
+            return Err("table.get does not match `ExternRef(Some(..))`!".into());
+        };
+
+        assert!(v.is_some());
+        let v = v.unwrap();
+        assert_eq!(*v, 1u32);
+
+        let extern_ref = ExternRef::new(&mut store, 2u32);
+        table
+            .set(&mut store, 0, Value::ExternRef(Some(extern_ref)))
+            .map_err(|e| e.to_string())?;
+
+        let v = table.get(&mut store, 0);
+        assert!(v.is_some());
+        let v = v.unwrap();
+
+        let v = if let Value::ExternRef(Some(ext)) = v {
+            ext.downcast::<u32>(&mut store)
+        } else {
+            return Err("table.get does not match `ExternRef(Some(..))`!".into());
+        };
+
+        assert!(v.is_some());
+        let v = v.unwrap();
+        assert_eq!(*v, 2u32);
+    }
+
     Ok(())
 }
 
@@ -141,15 +221,20 @@ fn table_grow() -> Result<(), String> {
         let f = Function::new_typed(&mut store, |num: i32| num + 1);
         let table = Table::new(&mut store, table_type, Value::FuncRef(Some(f.clone())))
             .map_err(|e| format!("{e:?}"))?;
+
+        let old_len = table.grow(&mut store, 1, Value::FuncRef(Some(f.clone())));
+        assert_eq!(0, old_len.unwrap());
+        let old_len = table.grow(&mut store, 1, Value::FuncRef(Some(f.clone())));
+        assert_eq!(1, old_len.unwrap());
+
         // Growing to a bigger maximum should return None
         let old_len = table.grow(&mut store, 12, Value::FuncRef(Some(f.clone())));
         assert!(old_len.is_err());
 
-        // Growing to a bigger maximum should return None
         let old_len = table
             .grow(&mut store, 5, Value::FuncRef(Some(f)))
             .map_err(|e| format!("{e:?}"))?;
-        assert_eq!(old_len, 0);
+        assert_eq!(old_len, 2);
     }
 
     Ok(())
@@ -165,7 +250,7 @@ fn table_copy() -> Result<(), String> {
 fn memory_new() -> Result<(), String> {
     let mut store = Store::default();
     let memory_type = MemoryType {
-        shared: false,
+        shared: if cfg!(feature = "wamr") { true } else { false },
         minimum: Pages(0),
         maximum: Some(Pages(10)),
     };
@@ -176,6 +261,10 @@ fn memory_new() -> Result<(), String> {
 }
 
 #[universal_test]
+#[cfg_attr(
+    feature = "wamr",
+    ignore = "wamr does not support direct calls to grow memory"
+)]
 fn memory_grow() -> Result<(), String> {
     let mut store = Store::default();
     let desc = MemoryType::new(Pages(10), Some(Pages(16)), false);
@@ -318,18 +407,22 @@ fn function_new_dynamic() -> Result<(), String> {
     );
     assert_eq!(function.ty(&store), function_type);
 
-    // Using array signature
-    let function_type = ([Type::V128], [Type::I32, Type::F32, Type::F64]);
-    let function = Function::new(
-        &mut store,
-        function_type,
-        |_values: &[Value]| unimplemented!(),
-    );
-    assert_eq!(function.ty(&store).params(), [Type::V128]);
-    assert_eq!(
-        function.ty(&store).results(),
-        [Type::I32, Type::F32, Type::F64]
-    );
+    // wasmi does not support V128 through its wasm_c_api bindings.
+    #[cfg(not(any(feature = "wasmi", feature = "v8")))]
+    {
+        // Using array signature
+        let function_type = ([Type::V128], [Type::I32, Type::F32, Type::F64]);
+        let function = Function::new(
+            &mut store,
+            function_type,
+            |_values: &[Value]| unimplemented!(),
+        );
+        assert_eq!(function.ty(&store).params(), [Type::V128]);
+        assert_eq!(
+            function.ty(&store).results(),
+            [Type::I32, Type::F32, Type::F64]
+        );
+    }
 
     Ok(())
 }
@@ -384,19 +477,22 @@ fn function_new_dynamic_env() -> Result<(), String> {
     );
     assert_eq!(function.ty(&store), function_type);
 
-    // Using array signature
-    let function_type = ([Type::V128], [Type::I32, Type::F32, Type::F64]);
-    let function = Function::new_with_env(
-        &mut store,
-        &env,
-        function_type,
-        |_env: FunctionEnvMut<MyEnv>, _values: &[Value]| unimplemented!(),
-    );
-    assert_eq!(function.ty(&store).params(), [Type::V128]);
-    assert_eq!(
-        function.ty(&store).results(),
-        [Type::I32, Type::F32, Type::F64]
-    );
-
+    // wasmi does not support V128 through its wasm_c_api bindings.
+    #[cfg(not(any(feature = "wasmi", feature = "v8")))]
+    {
+        // Using array signature
+        let function_type = ([Type::V128], [Type::I32, Type::F32, Type::F64]);
+        let function = Function::new_with_env(
+            &mut store,
+            &env,
+            function_type,
+            |_env: FunctionEnvMut<MyEnv>, _values: &[Value]| unimplemented!(),
+        );
+        assert_eq!(function.ty(&store).params(), [Type::V128]);
+        assert_eq!(
+            function.ty(&store).results(),
+            [Type::I32, Type::F32, Type::F64]
+        );
+    }
     Ok(())
 }
