@@ -4,7 +4,11 @@ use std::time::Duration;
 use crate::GraphQLApiFailure;
 use anyhow::{bail, Context as _};
 use cynic::{http::CynicReqwestError, GraphQlResponse, Operation};
+#[cfg(not(all(target_arch = "wasm32", target_os = "unknown")))]
+use reqwest::Proxy;
 use url::Url;
+#[cfg(all(target_arch = "wasm32", target_os = "unknown"))]
+struct Proxy;
 
 /// API client for the Wasmer API.
 ///
@@ -75,10 +79,14 @@ impl WasmerClient {
         })
     }
 
+    pub fn new(graphql_endpoint: Url, user_agent: &str) -> Result<Self, anyhow::Error> {
+        Self::new_with_proxy(graphql_endpoint, user_agent, None)
+    }
+
     pub fn new_with_proxy(
         graphql_endpoint: Url,
         user_agent: &str,
-        proxy: reqwest::Proxy,
+        proxy: Option<Proxy>,
     ) -> Result<Self, anyhow::Error> {
         let builder = {
             #[cfg(all(target_arch = "wasm32", target_os = "unknown"))]
@@ -89,7 +97,14 @@ impl WasmerClient {
                 .connect_timeout(Duration::from_secs(10))
                 .timeout(Duration::from_secs(90));
 
-            builder.proxy(proxy)
+            #[cfg(not(all(target_arch = "wasm32", target_os = "unknown")))]
+            if let Some(proxy) = proxy {
+                builder.proxy(proxy)
+            } else {
+                builder
+            }
+            #[cfg(all(target_arch = "wasm32", target_os = "unknown"))]
+            builder
         };
 
         let client = builder.build().context("failed to create reqwest client")?;
@@ -97,22 +112,6 @@ impl WasmerClient {
         Self::new_with_client(client, graphql_endpoint, user_agent)
     }
 
-    pub fn new(graphql_endpoint: Url, user_agent: &str) -> Result<Self, anyhow::Error> {
-        #[cfg(all(target_arch = "wasm32", target_os = "unknown"))]
-        let client = reqwest::Client::builder()
-            .build()
-            .context("could not construct http client")?;
-
-        #[cfg(not(all(target_arch = "wasm32", target_os = "unknown")))]
-        let client = reqwest::Client::builder()
-            .connect_timeout(Duration::from_secs(10))
-            .timeout(Duration::from_secs(90))
-            .build()
-            .context("could not construct http client")?;
-
-        Self::new_with_client(client, graphql_endpoint, user_agent)
-    }
-
     pub fn with_auth_token(mut self, auth_token: String) -> Self {
         self.auth_token = Some(auth_token);
         self
