@@ -4,12 +4,12 @@ use anyhow::{Context, Result};
 use clap::Parser;
 use std::fs;
 use std::path::{Path, PathBuf};
-use wasmer_compiler::{ArtifactBuild, ArtifactCreate, ModuleEnvironment};
-use wasmer_types::entity::PrimaryMap;
-use wasmer_types::{
-    Architecture, CompileError, CpuFeature, MemoryIndex, MemoryStyle, TableIndex, TableStyle,
-    Target, Triple,
+use wasmer_compiler::{
+    types::target::{Architecture, CpuFeature, Target, Triple},
+    ArtifactBuild, ArtifactCreate, ModuleEnvironment,
 };
+use wasmer_types::entity::PrimaryMap;
+use wasmer_types::{CompileError, MemoryIndex, MemoryStyle, TableIndex, TableStyle};
 
 #[derive(Debug, Parser)]
 /// The options for the `wasmer compile` subcommand
@@ -82,7 +82,7 @@ impl Compile {
         }
         let tunables = self.store.get_tunables_for_target(&target)?;
 
-        println!("Compiler: {}", compiler_type.to_string());
+        println!("Compiler: {}", compiler_type);
         println!("Target: {}", target.triple());
 
         // compile and save the artifact (without using module from api)
