@@ -1,9 +1,9 @@
 use crate::store::StoreOptions;
 use anyhow::{bail, Context, Result};
 use clap::Parser;
-use std::path::PathBuf;
-use std::str::FromStr;
-use wasmer_types::{is_wasm, CpuFeature, Target, Triple};
+use std::{path::PathBuf, str::FromStr};
+use wasmer_compiler::types::target::{CpuFeature, Target, Triple};
+use wasmer_types::is_wasm;
 
 #[derive(Debug, Parser)]
 /// The options for the `wasmer validate` subcommand
