@@ -1,8 +1,7 @@
-use std::{fs, path::Path};
-
+use crate::config::WasmerEnv;
 use anyhow::Result;
 use clap::Parser;
-use wasmer_registry::wasmer_env::WasmerEnv;
+use std::{fs, path::Path};
 
 #[derive(Debug, Parser)]
 /// The options for the `wasmer cache` subcommand
@@ -21,7 +20,7 @@ impl Cache {
 
         match self.cmd {
             Cmd::Clean => {
-                clean(&cache_dir)?;
+                clean(cache_dir)?;
             }
             Cmd::Dir => {
                 println!("{}", self.env.cache_dir().display());
