@@ -2,13 +2,14 @@
 
 use super::func_environ::TargetEnvironment;
 use crate::std::string::ToString;
-use core::u32;
-use cranelift_codegen::binemit::Reloc;
-use cranelift_codegen::ir::{self, AbiParam};
-use cranelift_codegen::isa::TargetFrontendConfig;
+use cranelift_codegen::{
+    binemit::Reloc,
+    ir::{self, AbiParam},
+    isa::TargetFrontendConfig,
+};
 use cranelift_frontend::FunctionBuilder;
-use wasmer_compiler::wasmparser;
-use wasmer_types::{FunctionType, LibCall, RelocationKind, Type, WasmError, WasmResult};
+use wasmer_compiler::{types::relocation::RelocationKind, wasmparser};
+use wasmer_types::{FunctionType, LibCall, Type, WasmError, WasmResult};
 
 /// Helper function translate a Function signature into Cranelift Ir
 pub fn signature_to_cranelift_ir(
@@ -84,7 +85,7 @@ pub fn irreloc_to_relocationkind(reloc: Reloc) -> RelocationKind {
         Reloc::X86CallPLTRel4 => RelocationKind::X86CallPLTRel4,
         Reloc::X86GOTPCRel4 => RelocationKind::X86GOTPCRel4,
         Reloc::Arm64Call => RelocationKind::Arm64Call,
-        Reloc::RiscvCall => RelocationKind::RiscvCall,
+        Reloc::RiscvCallPlt => RelocationKind::RiscvCall,
         _ => panic!("The relocation {} is not yet supported.", reloc),
     }
 }
