@@ -1,4 +1,5 @@
 use crate::abi::Abi;
+use crate::error::{err, err_nt};
 use crate::translator::intrinsics::{type_to_llvm, Intrinsics};
 use inkwell::{
     attributes::{Attribute, AttributeLoc},
@@ -46,7 +47,7 @@ impl Abi for X86_64SystemV {
         let user_param_types = sig.params().iter().map(|&ty| type_to_llvm(intrinsics, ty));
 
         let param_types =
-            std::iter::once(Ok(intrinsics.ctx_ptr_ty.as_basic_type_enum())).chain(user_param_types);
+            std::iter::once(Ok(intrinsics.ptr_ty.as_basic_type_enum())).chain(user_param_types);
 
         // TODO: figure out how many bytes long vmctx is, and mark it dereferenceable. (no need to mark it nonnull once we do this.)
         let vmctx_attributes = |i: u32| {
@@ -258,7 +259,7 @@ impl Abi for X86_64SystemV {
                     .collect::<Result<_, _>>()?;
 
                 let sret = context.struct_type(&basic_types, false);
-                let sret_ptr = sret.ptr_type(AddressSpace::default());
+                let sret_ptr = context.ptr_type(AddressSpace::default());
 
                 let param_types =
                     std::iter::once(Ok(sret_ptr.as_basic_type_enum())).chain(param_types);
@@ -295,7 +296,7 @@ impl Abi for X86_64SystemV {
         ctx_ptr: PointerValue<'ctx>,
         values: &[BasicValueEnum<'ctx>],
         intrinsics: &Intrinsics<'ctx>,
-    ) -> Vec<BasicValueEnum<'ctx>> {
+    ) -> Result<Vec<BasicValueEnum<'ctx>>, CompileError> {
         // If it's an sret, allocate the return space.
         let sret = if llvm_fn_ty.get_return_type().is_none() && func_sig.results().len() > 1 {
             let llvm_params: Vec<_> = func_sig
@@ -306,20 +307,22 @@ impl Abi for X86_64SystemV {
             let llvm_params = llvm_fn_ty
                 .get_context()
                 .struct_type(llvm_params.as_slice(), false);
-            Some(alloca_builder.build_alloca(llvm_params, "sret"))
+            Some(err!(alloca_builder.build_alloca(llvm_params, "sret")))
         } else {
             None
         };
 
         let values = std::iter::once(ctx_ptr.as_basic_value_enum()).chain(values.iter().copied());
 
-        if let Some(sret) = sret {
+        let ret = if let Some(sret) = sret {
             std::iter::once(sret.as_basic_value_enum())
                 .chain(values)
                 .collect()
         } else {
             values.collect()
-        }
+        };
+
+        Ok(ret)
     }
 
     // Given a CallSite, extract the returned values and return them in a Vec.
@@ -329,62 +332,68 @@ impl Abi for X86_64SystemV {
         intrinsics: &Intrinsics<'ctx>,
         call_site: CallSiteValue<'ctx>,
         func_sig: &FuncSig,
-    ) -> Vec<BasicValueEnum<'ctx>> {
-        let split_i64 = |value: IntValue<'ctx>| -> (IntValue<'ctx>, IntValue<'ctx>) {
-            assert!(value.get_type() == intrinsics.i64_ty);
-            let low = builder.build_int_truncate(value, intrinsics.i32_ty, "");
-            let lshr =
-                builder.build_right_shift(value, intrinsics.i64_ty.const_int(32, false), false, "");
-            let high = builder.build_int_truncate(lshr, intrinsics.i32_ty, "");
-            (low, high)
-        };
+    ) -> Result<Vec<BasicValueEnum<'ctx>>, CompileError> {
+        let split_i64 =
+            |value: IntValue<'ctx>| -> Result<(IntValue<'ctx>, IntValue<'ctx>), CompileError> {
+                assert!(value.get_type() == intrinsics.i64_ty);
+                let low = err!(builder.build_int_truncate(value, intrinsics.i32_ty, ""));
+                let lshr = err!(builder.build_right_shift(
+                    value,
+                    intrinsics.i64_ty.const_int(32, false),
+                    false,
+                    ""
+                ));
+                let high = err!(builder.build_int_truncate(lshr, intrinsics.i32_ty, ""));
+                Ok((low, high))
+            };
 
         let f32x2_ty = intrinsics.f32_ty.vec_type(2).as_basic_type_enum();
-        let extract_f32x2 = |value: VectorValue<'ctx>| -> (FloatValue<'ctx>, FloatValue<'ctx>) {
+        let extract_f32x2 = |value: VectorValue<'ctx>| -> Result<(FloatValue<'ctx>, FloatValue<'ctx>), CompileError> {
             assert!(value.get_type() == f32x2_ty.into_vector_type());
-            let ret0 = builder
-                .build_extract_element(value, intrinsics.i32_ty.const_int(0, false), "")
+            let ret0 = err!(builder
+                .build_extract_element(value, intrinsics.i32_ty.const_int(0, false), ""))
                 .into_float_value();
-            let ret1 = builder
-                .build_extract_element(value, intrinsics.i32_ty.const_int(1, false), "")
+            let ret1 = err!(builder
+                .build_extract_element(value, intrinsics.i32_ty.const_int(1, false), ""))
                 .into_float_value();
-            (ret0, ret1)
+            Ok((ret0, ret1))
         };
 
-        let casted = |value: BasicValueEnum<'ctx>, ty: Type| -> BasicValueEnum<'ctx> {
-            match ty {
-                Type::I32 => {
-                    assert!(
-                        value.get_type() == intrinsics.i32_ty.as_basic_type_enum()
-                            || value.get_type() == intrinsics.f32_ty.as_basic_type_enum()
-                    );
-                    builder.build_bitcast(value, intrinsics.i32_ty, "")
+        let casted =
+            |value: BasicValueEnum<'ctx>, ty: Type| -> Result<BasicValueEnum<'ctx>, CompileError> {
+                match ty {
+                    Type::I32 => {
+                        assert!(
+                            value.get_type() == intrinsics.i32_ty.as_basic_type_enum()
+                                || value.get_type() == intrinsics.f32_ty.as_basic_type_enum()
+                        );
+                        err_nt!(builder.build_bit_cast(value, intrinsics.i32_ty, ""))
+                    }
+                    Type::F32 => {
+                        assert!(
+                            value.get_type() == intrinsics.i32_ty.as_basic_type_enum()
+                                || value.get_type() == intrinsics.f32_ty.as_basic_type_enum()
+                        );
+                        err_nt!(builder.build_bit_cast(value, intrinsics.f32_ty, ""))
+                    }
+                    _ => panic!("should only be called to repack 32-bit values"),
                 }
-                Type::F32 => {
-                    assert!(
-                        value.get_type() == intrinsics.i32_ty.as_basic_type_enum()
-                            || value.get_type() == intrinsics.f32_ty.as_basic_type_enum()
-                    );
-                    builder.build_bitcast(value, intrinsics.f32_ty, "")
-                }
-                _ => panic!("should only be called to repack 32-bit values"),
-            }
-        };
+            };
 
         if let Some(basic_value) = call_site.try_as_basic_value().left() {
             if func_sig.results().len() > 1 {
                 if basic_value.get_type() == intrinsics.i64_ty.as_basic_type_enum() {
                     assert!(func_sig.results().len() == 2);
                     let value = basic_value.into_int_value();
-                    let (low, high) = split_i64(value);
-                    let low = casted(low.into(), func_sig.results()[0]);
-                    let high = casted(high.into(), func_sig.results()[1]);
-                    return vec![low, high];
+                    let (low, high) = split_i64(value)?;
+                    let low = casted(low.into(), func_sig.results()[0])?;
+                    let high = casted(high.into(), func_sig.results()[1])?;
+                    return Ok(vec![low, high]);
                 }
                 if basic_value.get_type() == f32x2_ty {
                     assert!(func_sig.results().len() == 2);
-                    let (ret0, ret1) = extract_f32x2(basic_value.into_vector_value());
-                    return vec![ret0.into(), ret1.into()];
+                    let (ret0, ret1) = extract_f32x2(basic_value.into_vector_value())?;
+                    return Ok(vec![ret0.into(), ret1.into()]);
                 }
                 let struct_value = basic_value.into_struct_value();
                 let rets = (0..struct_value.get_type().count_fields())
@@ -401,7 +410,7 @@ impl Abi for X86_64SystemV {
                     })
                     .collect::<Vec<i32>>();
 
-                match func_sig_returns_bitwidths.as_slice() {
+                let ret = match func_sig_returns_bitwidths.as_slice() {
                     [32, 64] | [64, 32] | [64, 64] => {
                         assert!(func_sig.results().len() == 2);
                         vec![rets[0], rets[1]]
@@ -411,14 +420,14 @@ impl Abi for X86_64SystemV {
                             == intrinsics.f32_ty.vec_type(2).as_basic_type_enum() =>
                     {
                         assert!(func_sig.results().len() == 3);
-                        let (rets0, rets1) = extract_f32x2(rets[0].into_vector_value());
+                        let (rets0, rets1) = extract_f32x2(rets[0].into_vector_value())?;
                         vec![rets0.into(), rets1.into(), rets[1]]
                     }
                     [32, 32, _] => {
                         assert!(func_sig.results().len() == 3);
-                        let (low, high) = split_i64(rets[0].into_int_value());
-                        let low = casted(low.into(), func_sig.results()[0]);
-                        let high = casted(high.into(), func_sig.results()[1]);
+                        let (low, high) = split_i64(rets[0].into_int_value())?;
+                        let low = casted(low.into(), func_sig.results()[0])?;
+                        let high = casted(high.into(), func_sig.results()[1])?;
                         vec![low, high, rets[1]]
                     }
                     [64, 32, 32]
@@ -426,14 +435,14 @@ impl Abi for X86_64SystemV {
                             == intrinsics.f32_ty.vec_type(2).as_basic_type_enum() =>
                     {
                         assert!(func_sig.results().len() == 3);
-                        let (rets1, rets2) = extract_f32x2(rets[1].into_vector_value());
+                        let (rets1, rets2) = extract_f32x2(rets[1].into_vector_value())?;
                         vec![rets[0], rets1.into(), rets2.into()]
                     }
                     [64, 32, 32] => {
                         assert!(func_sig.results().len() == 3);
-                        let (rets1, rets2) = split_i64(rets[1].into_int_value());
-                        let rets1 = casted(rets1.into(), func_sig.results()[1]);
-                        let rets2 = casted(rets2.into(), func_sig.results()[2]);
+                        let (rets1, rets2) = split_i64(rets[1].into_int_value())?;
+                        let rets1 = casted(rets1.into(), func_sig.results()[1])?;
+                        let rets2 = casted(rets2.into(), func_sig.results()[2])?;
                         vec![rets[0], rets1, rets2]
                     }
                     [32, 32, 32, 32] => {
@@ -441,32 +450,34 @@ impl Abi for X86_64SystemV {
                         let (low0, high0) = if rets[0].get_type()
                             == intrinsics.f32_ty.vec_type(2).as_basic_type_enum()
                         {
-                            let (x, y) = extract_f32x2(rets[0].into_vector_value());
+                            let (x, y) = extract_f32x2(rets[0].into_vector_value())?;
                             (x.into(), y.into())
                         } else {
-                            let (x, y) = split_i64(rets[0].into_int_value());
+                            let (x, y) = split_i64(rets[0].into_int_value())?;
                             (x.into(), y.into())
                         };
                         let (low1, high1) = if rets[1].get_type()
                             == intrinsics.f32_ty.vec_type(2).as_basic_type_enum()
                         {
-                            let (x, y) = extract_f32x2(rets[1].into_vector_value());
+                            let (x, y) = extract_f32x2(rets[1].into_vector_value())?;
                             (x.into(), y.into())
                         } else {
-                            let (x, y) = split_i64(rets[1].into_int_value());
+                            let (x, y) = split_i64(rets[1].into_int_value())?;
                             (x.into(), y.into())
                         };
-                        let low0 = casted(low0, func_sig.results()[0]);
-                        let high0 = casted(high0, func_sig.results()[1]);
-                        let low1 = casted(low1, func_sig.results()[2]);
-                        let high1 = casted(high1, func_sig.results()[3]);
+                        let low0 = casted(low0, func_sig.results()[0])?;
+                        let high0 = casted(high0, func_sig.results()[1])?;
+                        let low1 = casted(low1, func_sig.results()[2])?;
+                        let high1 = casted(high1, func_sig.results()[3])?;
                         vec![low0, high0, low1, high1]
                     }
                     _ => unreachable!("expected an sret for this type"),
-                }
+                };
+
+                Ok(ret)
             } else {
                 assert!(func_sig.results().len() == 1);
-                vec![basic_value]
+                Ok(vec![basic_value])
             }
         } else {
             assert!(call_site.count_arguments() > 0); // Either sret or vmctx.
@@ -497,19 +508,18 @@ impl Abi for X86_64SystemV {
                     .get_context()
                     .struct_type(llvm_results.as_slice(), false);
 
-                let struct_value = builder
-                    .build_load(struct_type, sret, "")
-                    .into_struct_value();
+                let struct_value =
+                    err!(builder.build_load(struct_type, sret, "")).into_struct_value();
                 let mut rets: Vec<_> = Vec::new();
                 for i in 0..struct_value.get_type().count_fields() {
                     let value = builder.build_extract_value(struct_value, i, "").unwrap();
                     rets.push(value);
                 }
                 assert!(func_sig.results().len() == rets.len());
-                rets
+                Ok(rets)
             } else {
                 assert!(func_sig.results().is_empty());
-                vec![]
+                Ok(vec![])
             }
         }
     }
@@ -565,24 +575,31 @@ impl Abi for X86_64SystemV {
             assert!(low.get_type() == intrinsics.i32_ty.as_basic_type_enum());
             assert!(high.get_type() == intrinsics.i32_ty.as_basic_type_enum());
             let (low, high) = (low.into_int_value(), high.into_int_value());
-            let low = builder.build_int_z_extend(low, intrinsics.i64_ty, "");
-            let high = builder.build_int_z_extend(high, intrinsics.i64_ty, "");
-            let high = builder.build_left_shift(high, intrinsics.i64_ty.const_int(32, false), "");
-            builder.build_or(low, high, "").as_basic_value_enum()
+            let low = err!(builder.build_int_z_extend(low, intrinsics.i64_ty, ""));
+            let high = err!(builder.build_int_z_extend(high, intrinsics.i64_ty, ""));
+            let high =
+                err!(builder.build_left_shift(high, intrinsics.i64_ty.const_int(32, false), ""));
+            err_nt!(builder
+                .build_or(low, high, "")
+                .map(|v| v.as_basic_value_enum()))
         };
 
         let pack_f32s = |first: BasicValueEnum<'ctx>,
                          second: BasicValueEnum<'ctx>|
-         -> BasicValueEnum<'ctx> {
+         -> Result<BasicValueEnum<'ctx>, CompileError> {
             assert!(first.get_type() == intrinsics.f32_ty.as_basic_type_enum());
             assert!(second.get_type() == intrinsics.f32_ty.as_basic_type_enum());
             let (first, second) = (first.into_float_value(), second.into_float_value());
             let vec_ty = intrinsics.f32_ty.vec_type(2);
-            let vec =
-                builder.build_insert_element(vec_ty.get_undef(), first, intrinsics.i32_zero, "");
-            builder
+            let vec = err!(builder.build_insert_element(
+                vec_ty.get_undef(),
+                first,
+                intrinsics.i32_zero,
+                ""
+            ));
+            err_nt!(builder
                 .build_insert_element(vec, second, intrinsics.i32_ty.const_int(1, false), "")
-                .as_basic_value_enum()
+                .map(|v| v.as_basic_value_enum()))
         };
 
         let build_struct = |ty: StructType<'ctx>, values: &[BasicValueEnum<'ctx>]| {
@@ -598,11 +615,11 @@ impl Abi for X86_64SystemV {
 
         Ok(match *values {
             [one_value] => one_value,
-            [v1, v2] if is_f32(v1) && is_f32(v2) => pack_f32s(v1, v2),
+            [v1, v2] if is_f32(v1) && is_f32(v2) => pack_f32s(v1, v2)?,
             [v1, v2] if is_32(v1) && is_32(v2) => {
-                let v1 = builder.build_bitcast(v1, intrinsics.i32_ty, "");
-                let v2 = builder.build_bitcast(v2, intrinsics.i32_ty, "");
-                pack_i32s(v1, v2)
+                let v1 = err!(builder.build_bit_cast(v1, intrinsics.i32_ty, ""));
+                let v2 = err!(builder.build_bit_cast(v2, intrinsics.i32_ty, ""));
+                pack_i32s(v1, v2)?
             }
             [v1, v2] => {
                 assert!(!(is_32(v1) && is_32(v2)));
@@ -613,42 +630,42 @@ impl Abi for X86_64SystemV {
             }
             [v1, v2, v3] if is_f32(v1) && is_f32(v2) => build_struct(
                 func_type.get_return_type().unwrap().into_struct_type(),
-                &[pack_f32s(v1, v2), v3],
+                &[pack_f32s(v1, v2)?, v3],
             ),
             [v1, v2, v3] if is_32(v1) && is_32(v2) => {
-                let v1 = builder.build_bitcast(v1, intrinsics.i32_ty, "");
-                let v2 = builder.build_bitcast(v2, intrinsics.i32_ty, "");
+                let v1 = err!(builder.build_bit_cast(v1, intrinsics.i32_ty, ""));
+                let v2 = err!(builder.build_bit_cast(v2, intrinsics.i32_ty, ""));
                 build_struct(
                     func_type.get_return_type().unwrap().into_struct_type(),
-                    &[pack_i32s(v1, v2), v3],
+                    &[pack_i32s(v1, v2)?, v3],
                 )
             }
             [v1, v2, v3] if is_64(v1) && is_f32(v2) && is_f32(v3) => build_struct(
                 func_type.get_return_type().unwrap().into_struct_type(),
-                &[v1, pack_f32s(v2, v3)],
+                &[v1, pack_f32s(v2, v3)?],
             ),
             [v1, v2, v3] if is_64(v1) && is_32(v2) && is_32(v3) => {
-                let v2 = builder.build_bitcast(v2, intrinsics.i32_ty, "");
-                let v3 = builder.build_bitcast(v3, intrinsics.i32_ty, "");
+                let v2 = err!(builder.build_bit_cast(v2, intrinsics.i32_ty, ""));
+                let v3 = err!(builder.build_bit_cast(v3, intrinsics.i32_ty, ""));
                 build_struct(
                     func_type.get_return_type().unwrap().into_struct_type(),
-                    &[v1, pack_i32s(v2, v3)],
+                    &[v1, pack_i32s(v2, v3)?],
                 )
             }
             [v1, v2, v3, v4] if is_32(v1) && is_32(v2) && is_32(v3) && is_32(v4) => {
                 let v1v2_pack = if is_f32(v1) && is_f32(v2) {
-                    pack_f32s(v1, v2)
+                    pack_f32s(v1, v2)?
                 } else {
-                    let v1 = builder.build_bitcast(v1, intrinsics.i32_ty, "");
-                    let v2 = builder.build_bitcast(v2, intrinsics.i32_ty, "");
-                    pack_i32s(v1, v2)
+                    let v1 = err!(builder.build_bit_cast(v1, intrinsics.i32_ty, ""));
+                    let v2 = err!(builder.build_bit_cast(v2, intrinsics.i32_ty, ""));
+                    pack_i32s(v1, v2)?
                 };
                 let v3v4_pack = if is_f32(v3) && is_f32(v4) {
-                    pack_f32s(v3, v4)
+                    pack_f32s(v3, v4)?
                 } else {
-                    let v3 = builder.build_bitcast(v3, intrinsics.i32_ty, "");
-                    let v4 = builder.build_bitcast(v4, intrinsics.i32_ty, "");
-                    pack_i32s(v3, v4)
+                    let v3 = err!(builder.build_bit_cast(v3, intrinsics.i32_ty, ""));
+                    let v4 = err!(builder.build_bit_cast(v4, intrinsics.i32_ty, ""));
+                    pack_i32s(v3, v4)?
                 };
                 build_struct(
                     func_type.get_return_type().unwrap().into_struct_type(),
