@@ -1,23 +1,23 @@
-use crate::abi::{get_abi, Abi};
-use crate::config::{CompiledKind, LLVM};
-use crate::object_file::{load_object_file, CompiledFunction};
-use crate::translator::intrinsics::{type_to_llvm, type_to_llvm_ptr, Intrinsics};
-use inkwell::values::BasicMetadataValueEnum;
+use crate::{
+    abi::{get_abi, Abi},
+    config::{CompiledKind, LLVM},
+    error::{err, err_nt},
+    object_file::{load_object_file, CompiledFunction},
+    translator::intrinsics::{type_to_llvm, type_to_llvm_ptr, Intrinsics},
+};
 use inkwell::{
     attributes::{Attribute, AttributeLoc},
     context::Context,
     module::{Linkage, Module},
-    passes::PassManager,
+    passes::PassBuilderOptions,
     targets::{FileType, TargetMachine},
-    types::{BasicType, FunctionType},
-    values::FunctionValue,
+    types::FunctionType,
+    values::{BasicMetadataValueEnum, FunctionValue},
     AddressSpace, DLLStorageClass,
 };
-use std::cmp;
-use std::convert::TryInto;
-use wasmer_types::{
-    CompileError, FunctionBody, FunctionType as FuncType, LocalFunctionIndex, RelocationTarget,
-};
+use std::{cmp, convert::TryInto};
+use wasmer_compiler::types::{function::FunctionBody, relocation::RelocationTarget};
+use wasmer_types::{CompileError, FunctionType as FuncType, LocalFunctionIndex};
 
 pub struct FuncTrampoline {
     ctx: Context,
@@ -58,9 +58,9 @@ impl FuncTrampoline {
                 .func_type_to_llvm(&self.ctx, &intrinsics, None, ty)?;
         let trampoline_ty = intrinsics.void_ty.fn_type(
             &[
-                intrinsics.ctx_ptr_ty.into(),                       // vmctx ptr
-                callee_ty.ptr_type(AddressSpace::default()).into(), // callee function address
-                intrinsics.i128_ptr_ty.into(),                      // in/out values ptr
+                intrinsics.ptr_ty.into(), // vmctx ptr
+                intrinsics.ptr_ty.into(), // callee function address
+                intrinsics.ptr_ty.into(), // in/out values ptr
             ],
             false,
         );
@@ -88,15 +88,20 @@ impl FuncTrampoline {
             callbacks.preopt_ir(&function, &module);
         }
 
-        let pass_manager = PassManager::create(());
+        let mut passes = vec![];
 
         if config.enable_verifier {
-            pass_manager.add_verifier_pass();
+            passes.push("verify");
         }
 
-        pass_manager.add_early_cse_pass();
-
-        pass_manager.run_on(&module);
+        passes.push("instcombine");
+        module
+            .run_passes(
+                passes.join(",").as_str(),
+                target_machine,
+                PassBuilderOptions::create(),
+            )
+            .unwrap();
 
         if let Some(ref callbacks) = config.callbacks {
             callbacks.postopt_ir(&function, &module);
@@ -208,15 +213,20 @@ impl FuncTrampoline {
             callbacks.preopt_ir(&function, &module);
         }
 
-        let pass_manager = PassManager::create(());
+        let mut passes = vec![];
 
         if config.enable_verifier {
-            pass_manager.add_verifier_pass();
+            passes.push("verify");
         }
 
-        pass_manager.add_early_cse_pass();
-
-        pass_manager.run_on(&module);
+        passes.push("early-cse");
+        module
+            .run_passes(
+                passes.join(",").as_str(),
+                target_machine,
+                PassBuilderOptions::create(),
+            )
+            .unwrap();
 
         if let Some(ref callbacks) = config.callbacks {
             callbacks.postopt_ir(&function, &module);
@@ -328,7 +338,7 @@ impl FuncTrampoline {
                 .collect::<Result<_, _>>()?;
 
             let sret_ty = context.struct_type(&basic_types, false);
-            args_vec.push(builder.build_alloca(sret_ty, "sret").into());
+            args_vec.push(err!(builder.build_alloca(sret_ty, "sret")).into());
         }
 
         args_vec.push(callee_vmctx_ptr.into());
@@ -336,45 +346,58 @@ impl FuncTrampoline {
         for (i, param_ty) in func_sig.params().iter().enumerate() {
             let index = intrinsics.i32_ty.const_int(i as _, false);
             let item_pointer = unsafe {
-                builder.build_in_bounds_gep(intrinsics.i128_ty, args_rets_ptr, &[index], "arg_ptr")
+                err!(builder.build_in_bounds_gep(
+                    intrinsics.i128_ty,
+                    args_rets_ptr,
+                    &[index],
+                    "arg_ptr"
+                ))
             };
 
             let casted_type = type_to_llvm(intrinsics, *param_ty)?;
             let casted_pointer_type = type_to_llvm_ptr(intrinsics, *param_ty)?;
 
-            let typed_item_pointer =
-                builder.build_pointer_cast(item_pointer, casted_pointer_type, "typed_arg_pointer");
+            let typed_item_pointer = err!(builder.build_pointer_cast(
+                item_pointer,
+                casted_pointer_type,
+                "typed_arg_pointer"
+            ));
 
-            let arg = builder.build_load(casted_type, typed_item_pointer, "arg");
+            let arg = err!(builder.build_load(casted_type, typed_item_pointer, "arg"));
             args_vec.push(arg.into());
         }
 
-        let call_site =
-            builder.build_indirect_call(llvm_func_type, func_ptr, args_vec.as_slice(), "call");
+        let call_site = err!(builder.build_indirect_call(
+            llvm_func_type,
+            func_ptr,
+            args_vec.as_slice(),
+            "call"
+        ));
         for (attr, attr_loc) in func_attrs {
             call_site.add_attribute(*attr_loc, *attr);
         }
 
         let rets = self
             .abi
-            .rets_from_call(&builder, intrinsics, call_site, func_sig);
-        let mut idx = 0;
-        rets.iter().for_each(|v| {
+            .rets_from_call(&builder, intrinsics, call_site, func_sig)?;
+        for (idx, v) in rets.into_iter().enumerate() {
             let ptr = unsafe {
-                builder.build_gep(
+                err!(builder.build_gep(
                     intrinsics.i128_ty,
                     args_rets_ptr,
-                    &[intrinsics.i32_ty.const_int(idx, false)],
+                    &[intrinsics.i32_ty.const_int(idx as u64, false)],
                     "",
-                )
+                ))
             };
-            let ptr =
-                builder.build_pointer_cast(ptr, v.get_type().ptr_type(AddressSpace::default()), "");
-            builder.build_store(ptr, *v);
-            idx += 1;
-        });
+            let ptr = err!(builder.build_pointer_cast(
+                ptr,
+                self.ctx.ptr_type(AddressSpace::default()),
+                ""
+            ));
+            err!(builder.build_store(ptr, v));
+        }
 
-        builder.build_return(None);
+        err!(builder.build_return(None));
         Ok(())
     }
 
@@ -390,61 +413,63 @@ impl FuncTrampoline {
         builder.position_at_end(entry_block);
 
         // Allocate stack space for the params and results.
-        let values = builder.build_alloca(
+        let values = err!(builder.build_alloca(
             intrinsics.i128_ty.array_type(cmp::max(
                 func_sig.params().len().try_into().unwrap(),
                 func_sig.results().len().try_into().unwrap(),
             )),
             "",
-        );
+        ));
 
         // Copy params to 'values'.
         let first_user_param = if self.abi.is_sret(func_sig)? { 2 } else { 1 };
         for i in 0..func_sig.params().len() {
             let ptr = unsafe {
-                builder.build_in_bounds_gep(
+                err!(builder.build_in_bounds_gep(
                     intrinsics.i128_ty,
                     values,
                     &[intrinsics.i32_ty.const_int(i.try_into().unwrap(), false)],
                     "args",
-                )
+                ))
             };
-            let ptr = builder
-                .build_bitcast(ptr, type_to_llvm_ptr(intrinsics, func_sig.params()[i])?, "")
-                .into_pointer_value();
-            builder.build_store(
+            let ptr = err!(builder.build_bit_cast(
+                ptr,
+                type_to_llvm_ptr(intrinsics, func_sig.params()[i])?,
+                ""
+            ))
+            .into_pointer_value();
+            err!(builder.build_store(
                 ptr,
                 trampoline_func
                     .get_nth_param(i as u32 + first_user_param)
                     .unwrap(),
-            );
+            ));
         }
 
         let callee_ptr_ty = intrinsics.void_ty.fn_type(
             &[
-                intrinsics.ctx_ptr_ty.into(),  // vmctx ptr
-                intrinsics.i128_ptr_ty.into(), // in/out values ptr
+                intrinsics.ptr_ty.into(), // vmctx ptr
+                intrinsics.ptr_ty.into(), // in/out values ptr
             ],
             false,
         );
-        let callee_ty = callee_ptr_ty.ptr_type(AddressSpace::default());
         let vmctx = self.abi.get_vmctx_ptr_param(&trampoline_func);
         let callee_ty =
-            builder.build_bitcast(vmctx, callee_ty.ptr_type(AddressSpace::default()), "");
-        let callee = builder
-            .build_load(intrinsics.ctx_ptr_ty, callee_ty.into_pointer_value(), "")
-            .into_pointer_value();
+            err!(builder.build_bit_cast(vmctx, self.ctx.ptr_type(AddressSpace::default()), ""));
+        let callee =
+            err!(builder.build_load(intrinsics.ptr_ty, callee_ty.into_pointer_value(), ""))
+                .into_pointer_value();
 
-        let values_ptr = builder.build_pointer_cast(values, intrinsics.i128_ptr_ty, "");
-        builder.build_indirect_call(
+        let values_ptr = err!(builder.build_pointer_cast(values, intrinsics.ptr_ty, ""));
+        err!(builder.build_indirect_call(
             callee_ptr_ty,
             callee,
             &[vmctx.into(), values_ptr.into()],
             "",
-        );
+        ));
 
         if func_sig.results().is_empty() {
-            builder.build_return(None);
+            err!(builder.build_return(None));
         } else {
             let results = func_sig
                 .results()
@@ -452,16 +477,19 @@ impl FuncTrampoline {
                 .enumerate()
                 .map(|(idx, ty)| {
                     let ptr = unsafe {
-                        builder.build_gep(
+                        err!(builder.build_gep(
                             intrinsics.i128_ty,
                             values,
                             &[intrinsics.i32_ty.const_int(idx.try_into().unwrap(), false)],
                             "",
-                        )
+                        ))
                     };
-                    let ptr =
-                        builder.build_pointer_cast(ptr, type_to_llvm_ptr(intrinsics, *ty)?, "");
-                    Ok(builder.build_load(type_to_llvm(intrinsics, *ty)?, ptr, ""))
+                    let ptr = err!(builder.build_pointer_cast(
+                        ptr,
+                        type_to_llvm_ptr(intrinsics, *ty)?,
+                        ""
+                    ));
+                    err_nt!(builder.build_load(type_to_llvm(intrinsics, *ty)?, ptr, ""))
                 })
                 .collect::<Result<Vec<_>, CompileError>>()?;
 
@@ -479,25 +507,26 @@ impl FuncTrampoline {
                 let mut struct_value = context.struct_type(&basic_types, false).get_undef();
 
                 for (idx, value) in results.iter().enumerate() {
-                    let value = builder.build_bitcast(
+                    let value = err!(builder.build_bit_cast(
                         *value,
                         type_to_llvm(intrinsics, func_sig.results()[idx])?,
                         "",
-                    );
-                    struct_value = builder
-                        .build_insert_value(struct_value, value, idx as u32, "")
-                        .unwrap()
-                        .into_struct_value();
+                    ));
+                    struct_value =
+                        err!(builder.build_insert_value(struct_value, value, idx as u32, ""))
+                            .into_struct_value();
                 }
-                builder.build_store(sret, struct_value);
-                builder.build_return(None);
+                err!(builder.build_store(sret, struct_value));
+                err!(builder.build_return(None));
             } else {
-                builder.build_return(Some(&self.abi.pack_values_for_register_return(
-                    intrinsics,
-                    &builder,
-                    results.as_slice(),
-                    &trampoline_func.get_type(),
-                )?));
+                err!(
+                    builder.build_return(Some(&self.abi.pack_values_for_register_return(
+                        intrinsics,
+                        &builder,
+                        results.as_slice(),
+                        &trampoline_func.get_type(),
+                    )?))
+                );
             }
         }
 
