@@ -140,20 +140,15 @@ impl From<JournalIpCidrV1> for virtual_net::IpCidr {
 
 impl From<wasi::ExitCode> for JournalExitCodeV1 {
     fn from(val: wasi::ExitCode) -> Self {
-        match val {
-            wasi::ExitCode::Errno(errno) => JournalExitCodeV1::Errno(errno as u16),
-            wasi::ExitCode::Other(id) => JournalExitCodeV1::Other(id),
-        }
+        JournalExitCodeV1::Other(val.raw())
     }
 }
 
 impl From<JournalExitCodeV1> for wasi::ExitCode {
     fn from(val: JournalExitCodeV1) -> Self {
         match val {
-            JournalExitCodeV1::Errno(errno) => {
-                wasi::ExitCode::Errno(errno.try_into().unwrap_or(wasi::Errno::Unknown))
-            }
-            JournalExitCodeV1::Other(id) => wasi::ExitCode::Other(id),
+            JournalExitCodeV1::Errno(errno) => wasi::ExitCode::from(errno),
+            JournalExitCodeV1::Other(id) => wasi::ExitCode::from(id),
         }
     }
 }
@@ -161,10 +156,8 @@ impl From<JournalExitCodeV1> for wasi::ExitCode {
 impl From<&'_ ArchivedJournalExitCodeV1> for wasi::ExitCode {
     fn from(val: &'_ ArchivedJournalExitCodeV1) -> Self {
         match val {
-            ArchivedJournalExitCodeV1::Errno(errno) => {
-                wasi::ExitCode::Errno((*errno).try_into().unwrap_or(wasi::Errno::Unknown))
-            }
-            ArchivedJournalExitCodeV1::Other(id) => wasi::ExitCode::Other(*id),
+            ArchivedJournalExitCodeV1::Errno(errno) => wasi::ExitCode::from(errno.to_native()),
+            ArchivedJournalExitCodeV1::Other(id) => wasi::ExitCode::from(id.to_native()),
         }
     }
 }
@@ -289,11 +282,11 @@ impl From<JournalEpollEventCtlV1> for wasi::EpollEventCtl {
 impl From<&'_ ArchivedJournalEpollEventCtlV1> for wasi::EpollEventCtl {
     fn from(val: &'_ ArchivedJournalEpollEventCtlV1) -> Self {
         Self {
-            events: wasi::EpollType::from_bits_truncate(val.events),
-            ptr: val.ptr,
-            fd: val.fd,
-            data1: val.data1,
-            data2: val.data2,
+            events: wasi::EpollType::from_bits_truncate(val.events.to_native()),
+            ptr: val.ptr.to_native(),
+            fd: val.fd.to_native(),
+            data1: val.data1.to_native(),
+            data2: val.data2.to_native(),
         }
     }
 }
@@ -593,7 +586,7 @@ impl From<&'_ ArchivedJournalThreadStartTypeV1> for ThreadStartType {
             ArchivedJournalThreadStartTypeV1::MainThread => ThreadStartType::MainThread,
             ArchivedJournalThreadStartTypeV1::ThreadSpawn { start_ptr } => {
                 ThreadStartType::ThreadSpawn {
-                    start_ptr: *start_ptr,
+                    start_ptr: start_ptr.to_native(),
                 }
             }
         }
@@ -625,10 +618,10 @@ impl From<JournalWasiMemoryLayout> for WasiMemoryLayout {
 impl From<&'_ ArchivedJournalWasiMemoryLayout> for WasiMemoryLayout {
     fn from(value: &'_ ArchivedJournalWasiMemoryLayout) -> Self {
         Self {
-            stack_upper: value.stack_upper,
-            stack_lower: value.stack_lower,
-            guard_size: value.guard_size,
-            stack_size: value.stack_size,
+            stack_upper: value.stack_upper.to_native(),
+            stack_lower: value.stack_lower.to_native(),
+            guard_size: value.guard_size.to_native(),
+            stack_size: value.stack_size.to_native(),
         }
     }
 }
@@ -664,7 +657,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     compressed_data,
                 },
             ) => Self::UpdateMemoryRegionV1 {
-                region: (*start)..(*end),
+                region: (start.to_native())..(end.to_native()),
                 compressed_data: Cow::Borrowed(compressed_data.as_ref()),
             },
             ArchivedJournalEntry::ProcessExitV1(ArchivedJournalEntryProcessExitV1 {
@@ -681,7 +674,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 start,
                 layout,
             }) => Self::SetThreadV1 {
-                id: *id,
+                id: id.to_native(),
                 call_stack: call_stack.as_ref().into(),
                 memory_stack: memory_stack.as_ref().into(),
                 store_data: store_data.as_ref().into(),
@@ -693,7 +686,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 id,
                 exit_code,
             }) => Self::CloseThreadV1 {
-                id: *id,
+                id: id.to_native(),
                 exit_code: exit_code.as_ref().map(|code| code.into()),
             },
             ArchivedJournalEntry::FileDescriptorWriteV1(
@@ -705,8 +698,8 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 },
             ) => Self::FileDescriptorWriteV1 {
                 data: data.as_ref().into(),
-                fd: *fd,
-                offset: *offset,
+                fd: fd.to_native(),
+                offset: offset.to_native(),
                 is_64bit: *is_64bit,
             },
             ArchivedJournalEntry::FileDescriptorSeekV1(
@@ -716,8 +709,8 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     ref whence,
                 },
             ) => Self::FileDescriptorSeekV1 {
-                fd: *fd,
-                offset: *offset,
+                fd: fd.to_native(),
+                offset: offset.to_native(),
                 whence: whence.into(),
             },
             ArchivedJournalEntry::OpenFileDescriptorV1(
@@ -732,28 +725,30 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     fs_flags,
                 },
             ) => Self::OpenFileDescriptorV1 {
-                fd: *fd,
-                dirfd: *dirfd,
-                dirflags: *dirflags,
+                fd: fd.to_native(),
+                dirfd: dirfd.to_native(),
+                dirflags: dirflags.to_native(),
                 path: String::from_utf8_lossy(path.as_ref()),
-                o_flags: wasi::Oflags::from_bits_truncate(*o_flags),
-                fs_rights_base: wasi::Rights::from_bits_truncate(*fs_rights_base),
-                fs_rights_inheriting: wasi::Rights::from_bits_truncate(*fs_rights_inheriting),
-                fs_flags: wasi::Fdflags::from_bits_truncate(*fs_flags),
+                o_flags: wasi::Oflags::from_bits_truncate(o_flags.to_native()),
+                fs_rights_base: wasi::Rights::from_bits_truncate(fs_rights_base.to_native()),
+                fs_rights_inheriting: wasi::Rights::from_bits_truncate(
+                    fs_rights_inheriting.to_native(),
+                ),
+                fs_flags: wasi::Fdflags::from_bits_truncate(fs_flags.to_native()),
             },
             ArchivedJournalEntry::CloseFileDescriptorV1(
                 ArchivedJournalEntryCloseFileDescriptorV1 { fd },
-            ) => Self::CloseFileDescriptorV1 { fd: *fd },
+            ) => Self::CloseFileDescriptorV1 { fd: fd.to_native() },
             ArchivedJournalEntry::RemoveDirectoryV1(ArchivedJournalEntryRemoveDirectoryV1 {
                 fd,
                 path,
             }) => Self::RemoveDirectoryV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 path: String::from_utf8_lossy(path.as_ref()),
             },
             ArchivedJournalEntry::UnlinkFileV1(ArchivedJournalEntryUnlinkFileV1 { fd, path }) => {
                 Self::UnlinkFileV1 {
-                    fd: *fd,
+                    fd: fd.to_native(),
                     path: String::from_utf8_lossy(path.as_ref()),
                 }
             }
@@ -763,9 +758,9 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 new_fd,
                 new_path,
             }) => Self::PathRenameV1 {
-                old_fd: *old_fd,
+                old_fd: old_fd.to_native(),
                 old_path: String::from_utf8_lossy(old_path.as_ref()),
-                new_fd: *new_fd,
+                new_fd: new_fd.to_native(),
                 new_path: String::from_utf8_lossy(new_path.as_ref()),
             },
             ArchivedJournalEntry::SnapshotV1(ArchivedJournalEntrySnapshotV1 {
@@ -773,7 +768,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 ref trigger,
             }) => Self::SnapshotV1 {
                 when: SystemTime::UNIX_EPOCH
-                    .checked_add((*since_epoch).try_into().unwrap())
+                    .checked_add((*since_epoch).into())
                     .unwrap_or(SystemTime::UNIX_EPOCH),
                 trigger: trigger.into(),
             },
@@ -782,13 +777,13 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 time,
             }) => Self::SetClockTimeV1 {
                 clock_id: clock_id.into(),
-                time: *time,
+                time: time.to_native(),
             },
             ArchivedJournalEntry::RenumberFileDescriptorV1(
                 ArchivedJournalEntryRenumberFileDescriptorV1 { old_fd, new_fd },
             ) => Self::RenumberFileDescriptorV1 {
-                old_fd: *old_fd,
-                new_fd: *new_fd,
+                old_fd: old_fd.to_native(),
+                new_fd: new_fd.to_native(),
             },
             ArchivedJournalEntry::DuplicateFileDescriptorV1(
                 ArchivedJournalEntryDuplicateFileDescriptorV1 {
@@ -796,14 +791,14 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     copied_fd: new_fd,
                 },
             ) => Self::DuplicateFileDescriptorV1 {
-                original_fd: *old_fd,
-                copied_fd: *new_fd,
+                original_fd: old_fd.to_native(),
+                copied_fd: new_fd.to_native(),
             },
             ArchivedJournalEntry::CreateDirectoryV1(ArchivedJournalEntryCreateDirectoryV1 {
                 fd,
                 path,
             }) => Self::CreateDirectoryV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 path: String::from_utf8_lossy(path.as_ref()),
             },
             ArchivedJournalEntry::PathSetTimesV1(ArchivedJournalEntryPathSetTimesV1 {
@@ -814,12 +809,12 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 st_mtim,
                 fst_flags,
             }) => Self::PathSetTimesV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 path: String::from_utf8_lossy(path.as_ref()),
-                flags: *flags,
-                st_atim: *st_atim,
-                st_mtim: *st_mtim,
-                fst_flags: wasi::Fstflags::from_bits_truncate(*fst_flags),
+                flags: flags.to_native(),
+                st_atim: st_atim.to_native(),
+                st_mtim: st_mtim.to_native(),
+                fst_flags: wasi::Fstflags::from_bits_truncate(fst_flags.to_native()),
             },
             ArchivedJournalEntry::FileDescriptorSetTimesV1(
                 ArchivedJournalEntryFileDescriptorSetTimesV1 {
@@ -829,22 +824,22 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     fst_flags,
                 },
             ) => Self::FileDescriptorSetTimesV1 {
-                fd: *fd,
-                st_atim: *st_atim,
-                st_mtim: *st_mtim,
-                fst_flags: wasi::Fstflags::from_bits_truncate(*fst_flags),
+                fd: fd.to_native(),
+                st_atim: st_atim.to_native(),
+                st_mtim: st_mtim.to_native(),
+                fst_flags: wasi::Fstflags::from_bits_truncate(fst_flags.to_native()),
             },
             ArchivedJournalEntry::FileDescriptorSetSizeV1(
                 ArchivedJournalEntryFileDescriptorSetSizeV1 { fd, st_size },
             ) => Self::FileDescriptorSetSizeV1 {
-                fd: *fd,
-                st_size: *st_size,
+                fd: fd.to_native(),
+                st_size: st_size.to_native(),
             },
             ArchivedJournalEntry::FileDescriptorSetFlagsV1(
                 ArchivedJournalEntryFileDescriptorSetFlagsV1 { fd, flags },
             ) => Self::FileDescriptorSetFlagsV1 {
-                fd: *fd,
-                flags: wasi::Fdflags::from_bits_truncate(*flags),
+                fd: fd.to_native(),
+                flags: wasi::Fdflags::from_bits_truncate(flags.to_native()),
             },
             ArchivedJournalEntry::FileDescriptorSetRightsV1(
                 ArchivedJournalEntryFileDescriptorSetRightsV1 {
@@ -853,9 +848,11 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     fs_rights_inheriting,
                 },
             ) => Self::FileDescriptorSetRightsV1 {
-                fd: *fd,
-                fs_rights_base: wasi::Rights::from_bits_truncate(*fs_rights_base),
-                fs_rights_inheriting: wasi::Rights::from_bits_truncate(*fs_rights_inheriting),
+                fd: fd.to_native(),
+                fs_rights_base: wasi::Rights::from_bits_truncate(fs_rights_base.to_native()),
+                fs_rights_inheriting: wasi::Rights::from_bits_truncate(
+                    fs_rights_inheriting.to_native(),
+                ),
             },
             ArchivedJournalEntry::FileDescriptorAdviseV1(
                 ArchivedJournalEntryFileDescriptorAdviseV1 {
@@ -865,17 +862,17 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     ref advice,
                 },
             ) => Self::FileDescriptorAdviseV1 {
-                fd: *fd,
-                offset: *offset,
-                len: *len,
+                fd: fd.to_native(),
+                offset: offset.to_native(),
+                len: len.to_native(),
                 advice: advice.into(),
             },
             ArchivedJournalEntry::FileDescriptorAllocateV1(
                 ArchivedJournalEntryFileDescriptorAllocateV1 { fd, offset, len },
             ) => Self::FileDescriptorAllocateV1 {
-                fd: *fd,
-                offset: *offset,
-                len: *len,
+                fd: fd.to_native(),
+                offset: offset.to_native(),
+                len: len.to_native(),
             },
             ArchivedJournalEntry::CreateHardLinkV1(ArchivedJournalEntryCreateHardLinkV1 {
                 old_fd,
@@ -884,10 +881,10 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 new_fd,
                 new_path,
             }) => Self::CreateHardLinkV1 {
-                old_fd: *old_fd,
+                old_fd: old_fd.to_native(),
                 old_path: String::from_utf8_lossy(old_path.as_ref()),
-                old_flags: *old_flags,
-                new_fd: *new_fd,
+                old_flags: old_flags.to_native(),
+                new_fd: new_fd.to_native(),
                 new_path: String::from_utf8_lossy(new_path.as_ref()),
             },
             ArchivedJournalEntry::CreateSymbolicLinkV1(
@@ -898,7 +895,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 },
             ) => Self::CreateSymbolicLinkV1 {
                 old_path: String::from_utf8_lossy(old_path.as_ref()),
-                fd: *fd,
+                fd: fd.to_native(),
                 new_path: String::from_utf8_lossy(new_path.as_ref()),
             },
             ArchivedJournalEntry::ChangeDirectoryV1(ArchivedJournalEntryChangeDirectoryV1 {
@@ -907,7 +904,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 path: String::from_utf8_lossy(path.as_ref()),
             },
             ArchivedJournalEntry::EpollCreateV1(ArchivedJournalEntryEpollCreateV1 { fd }) => {
-                Self::EpollCreateV1 { fd: *fd }
+                Self::EpollCreateV1 { fd: fd.to_native() }
             }
             ArchivedJournalEntry::EpollCtlV1(ArchivedJournalEntryEpollCtlV1 {
                 epfd,
@@ -915,9 +912,9 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 fd,
                 ref event,
             }) => Self::EpollCtlV1 {
-                epfd: *epfd,
+                epfd: epfd.to_native(),
                 op: op.into(),
-                fd: *fd,
+                fd: fd.to_native(),
                 event: event.as_ref().map(|e| e.into()),
             },
             ArchivedJournalEntry::TtySetV1(ArchivedJournalEntryTtySetV1 {
@@ -933,10 +930,10 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 line_feeds,
             }) => Self::TtySetV1 {
                 tty: wasi::Tty {
-                    cols: *cols,
-                    rows: *rows,
-                    width: *width,
-                    height: *height,
+                    cols: cols.to_native(),
+                    rows: rows.to_native(),
+                    width: width.to_native(),
+                    height: height.to_native(),
                     stdin_tty: *stdin_tty,
                     stdout_tty: *stdout_tty,
                     stderr_tty: *stderr_tty,
@@ -947,8 +944,8 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
             },
             ArchivedJournalEntry::CreatePipeV1(ArchivedJournalEntryCreatePipeV1 { fd1, fd2 }) => {
                 Self::CreatePipeV1 {
-                    fd1: *fd1,
-                    fd2: *fd2,
+                    fd1: fd1.to_native(),
+                    fd2: fd2.to_native(),
                 }
             }
             ArchivedJournalEntry::PortAddAddrV1(ArchivedJournalEntryPortAddAddrV1 { cidr }) => {
@@ -992,10 +989,8 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 }
                 .into(),
                 via_router: via_router.as_ipaddr(),
-                preferred_until: preferred_until
-                    .as_ref()
-                    .map(|time| (*time).try_into().unwrap()),
-                expires_at: expires_at.as_ref().map(|time| (*time).try_into().unwrap()),
+                preferred_until: preferred_until.as_ref().map(|time| (*time).into()),
+                expires_at: expires_at.as_ref().map(|time| (*time).into()),
             },
             ArchivedJournalEntry::PortRouteClearV1 => Self::PortRouteClearV1,
             ArchivedJournalEntry::PortRouteDelV1(ArchivedJournalEntryPortRouteDelV1 { ip }) => {
@@ -1009,19 +1004,19 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
             }) => Self::SocketOpenV1 {
                 af: af.into(),
                 ty: ty.into(),
-                pt: (*pt).try_into().unwrap_or(wasi::SockProto::Max),
-                fd: *fd,
+                pt: (pt.to_native()).try_into().unwrap_or(wasi::SockProto::Max),
+                fd: fd.to_native(),
             },
             ArchivedJournalEntry::SocketListenV1(ArchivedJournalEntrySocketListenV1 {
                 fd,
                 backlog,
             }) => Self::SocketListenV1 {
-                fd: *fd,
-                backlog: *backlog,
+                fd: fd.to_native(),
+                backlog: backlog.to_native(),
             },
             ArchivedJournalEntry::SocketBindV1(ArchivedJournalEntrySocketBindV1 { fd, addr }) => {
                 Self::SocketBindV1 {
-                    fd: *fd,
+                    fd: fd.to_native(),
                     addr: addr.as_socket_addr(),
                 }
             }
@@ -1030,7 +1025,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 local_addr,
                 peer_addr,
             }) => Self::SocketConnectedV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 local_addr: local_addr.as_socket_addr(),
                 peer_addr: peer_addr.as_socket_addr(),
             },
@@ -1042,11 +1037,11 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 fd_flags,
                 nonblocking,
             }) => Self::SocketAcceptedV1 {
-                listen_fd: *listen_fd,
-                fd: *fd,
+                listen_fd: listen_fd.to_native(),
+                fd: fd.to_native(),
                 local_addr: local_addr.as_socket_addr(),
                 peer_addr: peer_addr.as_socket_addr(),
-                fd_flags: wasi::Fdflags::from_bits_truncate(*fd_flags),
+                fd_flags: wasi::Fdflags::from_bits_truncate(fd_flags.to_native()),
                 non_blocking: *nonblocking,
             },
             ArchivedJournalEntry::SocketJoinIpv4MulticastV1(
@@ -1056,7 +1051,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     iface,
                 },
             ) => Self::SocketJoinIpv4MulticastV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 multiaddr: multiaddr.as_ipv4(),
                 iface: iface.as_ipv4(),
             },
@@ -1067,9 +1062,9 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     iface,
                 },
             ) => Self::SocketJoinIpv6MulticastV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 multi_addr: multiaddr.as_ipv6(),
-                iface: *iface,
+                iface: iface.to_native(),
             },
             ArchivedJournalEntry::SocketLeaveIpv4MulticastV1(
                 ArchivedJournalEntrySocketLeaveIpv4MulticastV1 {
@@ -1078,7 +1073,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     iface,
                 },
             ) => Self::SocketLeaveIpv4MulticastV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 multi_addr: multiaddr.as_ipv4(),
                 iface: iface.as_ipv4(),
             },
@@ -1089,9 +1084,9 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                     iface,
                 },
             ) => Self::SocketLeaveIpv6MulticastV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 multi_addr: multiaddr.as_ipv6(),
-                iface: *iface,
+                iface: iface.to_native(),
             },
             ArchivedJournalEntry::SocketSendFileV1(ArchivedJournalEntrySocketSendFileV1 {
                 socket_fd,
@@ -1099,10 +1094,10 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 offset,
                 count,
             }) => Self::SocketSendFileV1 {
-                socket_fd: *socket_fd,
-                file_fd: *file_fd,
-                offset: *offset,
-                count: *count,
+                socket_fd: socket_fd.to_native(),
+                file_fd: file_fd.to_native(),
+                offset: offset.to_native(),
+                count: count.to_native(),
             },
             ArchivedJournalEntry::SocketSendToV1(ArchivedJournalEntrySocketSendToV1 {
                 fd,
@@ -1111,9 +1106,9 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 addr,
                 is_64bit,
             }) => Self::SocketSendToV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 data: data.as_ref().into(),
-                flags: *flags,
+                flags: flags.to_native(),
                 addr: addr.as_socket_addr(),
                 is_64bit: *is_64bit,
             },
@@ -1123,9 +1118,9 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 flags,
                 is_64bit,
             }) => Self::SocketSendV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 data: data.as_ref().into(),
-                flags: *flags,
+                flags: flags.to_native(),
                 is_64bit: *is_64bit,
             },
             ArchivedJournalEntry::SocketSetOptFlagV1(ArchivedJournalEntrySocketSetOptFlagV1 {
@@ -1133,7 +1128,7 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 ref opt,
                 flag,
             }) => Self::SocketSetOptFlagV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 opt: opt.into(),
                 flag: *flag,
             },
@@ -1142,24 +1137,24 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 ref opt,
                 size,
             }) => Self::SocketSetOptSizeV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 opt: opt.into(),
-                size: *size,
+                size: size.to_native(),
             },
             ArchivedJournalEntry::SocketSetOptTimeV1(ArchivedJournalEntrySocketSetOptTimeV1 {
                 fd,
                 ref ty,
                 time,
             }) => Self::SocketSetOptTimeV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 ty: ty.into(),
-                time: time.as_ref().map(|time| (*time).try_into().unwrap()),
+                time: time.as_ref().map(|time| (*time).into()),
             },
             ArchivedJournalEntry::SocketShutdownV1(ArchivedJournalEntrySocketShutdownV1 {
                 fd,
                 ref how,
             }) => Self::SocketShutdownV1 {
-                fd: *fd,
+                fd: fd.to_native(),
                 how: how.into(),
             },
             ArchivedJournalEntry::CreateEventV1(ArchivedJournalEntryCreateEventV1 {
@@ -1167,9 +1162,9 @@ impl<'a> TryFrom<ArchivedJournalEntry<'a>> for JournalEntry<'a> {
                 flags,
                 fd,
             }) => Self::CreateEventV1 {
-                initial_val: *initial_val,
-                flags: *flags,
-                fd: *fd,
+                initial_val: initial_val.to_native(),
+                flags: flags.to_native(),
+                fd: fd.to_native(),
             },
         })
     }
