@@ -5,6 +5,14 @@ pub struct VMFunctionEnvironment {
     contents: Box<dyn Any + Send + 'static>,
 }
 
+impl std::fmt::Debug for VMFunctionEnvironment {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("VMFunctionEnvironment")
+            .field("contents", &(&*self.contents as *const _))
+            .finish()
+    }
+}
+
 impl VMFunctionEnvironment {
     /// Wraps the given value to expose it to Wasm code as a function context.
     pub fn new(val: impl Any + Send + 'static) -> Self {
