@@ -156,7 +156,7 @@ pub unsafe extern "C" fn wasmer_vm_memory32_grow(
         instance
             .memory_grow(memory_index, delta)
             .map(|pages| pages.0)
-            .unwrap_or(u32::max_value())
+            .unwrap_or(u32::MAX)
     })
 }
 
@@ -178,7 +178,7 @@ pub unsafe extern "C" fn wasmer_vm_imported_memory32_grow(
         instance
             .imported_memory_grow(memory_index, delta)
             .map(|pages| pages.0)
-            .unwrap_or(u32::max_value())
+            .unwrap_or(u32::MAX)
     })
 }
 
@@ -454,7 +454,7 @@ pub unsafe extern "C" fn wasmer_vm_table_grow(
 
         instance
             .table_grow(table_index, delta, init_value)
-            .unwrap_or(u32::max_value())
+            .unwrap_or(u32::MAX)
     })
 }
 
@@ -481,7 +481,7 @@ pub unsafe extern "C" fn wasmer_vm_imported_table_grow(
 
         instance
             .imported_table_grow(table_index, delta, init_value)
-            .unwrap_or(u32::max_value())
+            .unwrap_or(u32::MAX)
     })
 }
 
