@@ -7,6 +7,8 @@ pub mod signal;
 mod task_join_handle;
 pub mod thread;
 
+#[allow(unused_imports)]
+pub(crate) use process::WasiProcessInner;
 pub use task_join_handle::{
     OwnedTaskStatus, TaskJoinHandle, TaskStatus, TaskTerminatedError, VirtualTaskHandle,
 };
