@@ -72,10 +72,9 @@ mod sys_terminal_size {
     }
 }
 
-#[allow(unused_mut)]
+#[allow(unused_mut, unused_imports)]
 #[cfg(all(unix, not(target_os = "ios")))]
 mod sys {
-    #![allow(unused_imports)]
     use {
         libc::{
             c_int, tcsetattr, termios, ECHO, ECHOCTL, ECHOE, ECHOK, ECHONL, ICANON, ICRNL, IEXTEN,
