@@ -16,6 +16,16 @@ use crate::syscalls::*;
 pub fn fd_close(mut ctx: FunctionEnvMut<'_, WasiEnv>, fd: WasiFd) -> Result<Errno, WasiError> {
     wasi_try_ok!(WasiEnv::process_signals_and_exit(&mut ctx)?);
 
+    let env = ctx.data();
+    let (_, mut state) = unsafe { env.get_memory_and_wasi_state(&ctx, 0) };
+
+    if let Ok(pfd) = state.fs.get_fd(fd) {
+        if pfd.inode.is_preopened {
+            trace!("Skipping fd_close({})", fd);
+            return Ok(Errno::Success);
+        }
+    }
+
     // HACK: As a special case, we don't want to close fd 3 because it can break
     // some programs...
     // - On Wasix, we have some default fd, 0:stdin, 1:stdout, 2:stderr, 3:root
@@ -28,15 +38,13 @@ pub fn fd_close(mut ctx: FunctionEnvMut<'_, WasiEnv>, fd: WasiFd) -> Result<Errn
         return Ok(Errno::Success);
     }
 
-    let env = ctx.data();
-    let (_, mut state) = unsafe { env.get_memory_and_wasi_state(&ctx, 0) };
     wasi_try_ok!(state.fs.close_fd(fd));
 
     #[cfg(feature = "journal")]
     if env.enable_journal {
         JournalEffector::save_fd_close(&mut ctx, fd).map_err(|err| {
             tracing::error!("failed to save close descriptor event - {}", err);
-            WasiError::Exit(ExitCode::Errno(Errno::Fault))
+            WasiError::Exit(ExitCode::from(Errno::Fault))
         })?;
     }
 
