@@ -25,7 +25,7 @@ pub fn epoll_create<M: MemorySize + 'static>(
     if env.enable_journal {
         JournalEffector::save_epoll_create(&mut ctx, fd).map_err(|err| {
             tracing::error!("failed to save epoll_create event - {}", err);
-            WasiError::Exit(ExitCode::Errno(Errno::Fault))
+            WasiError::Exit(ExitCode::from(Errno::Fault))
         })?;
     }
 
