@@ -13,8 +13,11 @@ use wasmer::Type as ValueType;
 use wasmer::*;
 
 fn get_module(store: &Store) -> Result<Module> {
+    // Note: this module is also used to test indirect calls to imported
+    // functions, do not remove the call_indirect instruction
     let wat = r#"
-        (import "host" "0" (func))
+        (type (func))
+        (import "host" "0" (func $host_func_0 (type 0)))
         (import "host" "1" (func (param i32) (result i32)))
         (import "host" "2" (func (param i32) (param i64)))
         (import "host" "3" (func (param i32 i64 i32 f32 f64)))
@@ -22,7 +25,9 @@ fn get_module(store: &Store) -> Result<Module> {
         (export "memory" (memory $mem))
 
         (func $foo
-            call 0
+            i32.const 1
+            call_indirect (type 0)
+
             i32.const 0
             call 1
             i32.const 1
@@ -37,6 +42,8 @@ fn get_module(store: &Store) -> Result<Module> {
             f64.const 500
             call 3
         )
+        (table 2 2 funcref)
+        (elem (i32.const 1) func $host_func_0)
         (start $foo)
     "#;
 
