@@ -5,6 +5,10 @@ use std::collections::{HashMap, HashSet};
 use std::path::Path;
 use std::str;
 use wasmer::*;
+use wast::core::{AbstractHeapType, HeapType, WastArgCore, WastRetCore};
+use wast::token::{F32, F64};
+use wast::{lexer::Lexer, parser};
+use wast::{QuoteWat, Wast as WWast, WastArg};
 
 /// The wast test script language allows modules to be defined and actions
 /// to be performed on them.
@@ -92,12 +96,14 @@ impl Wast {
     fn perform_execute(&mut self, exec: wast::WastExecute<'_>) -> Result<Vec<Value>> {
         match exec {
             wast::WastExecute::Invoke(invoke) => self.perform_invoke(invoke),
-            wast::WastExecute::Module(mut module) => {
+            wast::WastExecute::Wat(mut module) => {
                 let binary = module.encode()?;
                 let result = self.instantiate(&binary);
                 result.map(|_| Vec::new())
             }
-            wast::WastExecute::Get { module, global } => self.get(module.map(|s| s.name()), global),
+            wast::WastExecute::Get { module, global, .. } => {
+                self.get(module.map(|s| s.name()), global)
+            }
         }
     }
 
@@ -105,7 +111,10 @@ impl Wast {
         let values = exec
             .args
             .iter()
-            .map(|a| self.runtime_value(a))
+            .map(|v| match v {
+                WastArg::Core(v) => self.runtime_value(v),
+                WastArg::Component(_) => bail!("expected component function, found core"),
+            })
             .collect::<Result<Vec<_>>>()?;
         self.invoke(exec.module.map(|i| i.name()), exec.name, &values)
     }
@@ -113,15 +122,21 @@ impl Wast {
     fn assert_return(
         &self,
         result: Result<Vec<Value>>,
-        results: &[wast::AssertExpression],
+        results: &[wast::WastRet<'_>],
     ) -> Result<()> {
         let values = result?;
         for (v, e) in values.iter().zip(results) {
-            if self.val_matches(v, e)? {
-                continue;
+            match e {
+                wast::WastRet::Core(e) => {
+                    if self.val_matches(v, e)? {
+                        continue;
+                    }
+                }
+                wast::WastRet::Component(_) => anyhow::bail!("Components not supported yet!"),
             }
+
             if let Value::V128(bits) = v {
-                if let wast::AssertExpression::V128(pattern) = e {
+                if let wast::WastRet::Core(WastRetCore::V128(pattern)) = e {
                     bail!(
                         "expected {:?}, got {:?} (v128 bits: {})",
                         e,
@@ -134,6 +149,22 @@ impl Wast {
         }
         Ok(())
     }
+    /// Define a module and register it.
+    fn wat(&mut self, mut wat: QuoteWat<'_>) -> Result<()> {
+        let (is_module, name) = match &wat {
+            QuoteWat::Wat(wast::Wat::Module(m)) => (true, m.id.map(|v| v.name())),
+            QuoteWat::QuoteModule(..) => (true, None),
+            QuoteWat::Wat(wast::Wat::Component(m)) => (false, m.id.map(|v| v.name())),
+            QuoteWat::QuoteComponent(..) => (false, None),
+        };
+        let bytes = wat.encode()?;
+        if is_module {
+            self.module(name, &bytes)?;
+        } else {
+            bail!("component-model support not enabled");
+        }
+        Ok(())
+    }
 
     fn assert_trap(&self, result: Result<Vec<Value>>, expected: &str) -> Result<()> {
         let actual = match result {
@@ -146,14 +177,11 @@ impl Wast {
         bail!("expected '{}', got '{}'", expected, actual)
     }
 
-    fn run_directive(&mut self, test: &Path, directive: wast::WastDirective) -> Result<()> {
+    fn run_directive(&mut self, _test: &Path, directive: wast::WastDirective) -> Result<()> {
         use wast::WastDirective::*;
 
         match directive {
-            Module(mut module) => {
-                let binary = module.encode()?;
-                self.module(module.id.map(|s| s.name()), &binary)?;
-            }
+            Wat(module) => self.wat(module)?,
             Register {
                 span: _,
                 name,
@@ -197,11 +225,7 @@ impl Wast {
                 module,
                 message,
             } => {
-                let wasm = match module {
-                    wast::QuoteModule::Module(mut m) => m.encode()?,
-                    wast::QuoteModule::Quote(list) => self.parse_quote_module(test, &list)?,
-                };
-                let err = match self.module(None, &wasm) {
+                let err = match self.wat(module) {
                     Ok(()) => bail!("expected module to fail to build"),
                     Err(e) => e,
                 };
@@ -214,9 +238,6 @@ impl Wast {
                     )
                 }
             }
-            QuoteModule { .. } => {
-                // Do nothing
-            }
             AssertException { .. } => {
                 // Do nothing for now
             }
@@ -226,10 +247,13 @@ impl Wast {
                 message: _,
             } => {
                 let mut module = match module {
-                    wast::QuoteModule::Module(m) => m,
+                    wast::QuoteWat::Wat(m) => m,
                     // This is a `*.wat` parser test which we're not
                     // interested in.
-                    wast::QuoteModule::Quote(_) => return Ok(()),
+                    wast::QuoteWat::QuoteModule(_, _) => return Ok(()),
+                    wast::QuoteWat::QuoteComponent(_, _) => {
+                        anyhow::bail!("Components not supported!")
+                    }
                 };
                 let bytes = module.encode()?;
                 if self.module(None, &bytes).is_ok() {
@@ -255,6 +279,8 @@ impl Wast {
                     )
                 }
             }
+            Thread(_) => anyhow::bail!("`thread` directives not implemented yet!"),
+            Wait { .. } => anyhow::bail!("`wait` directives not implemented yet!"),
         }
 
         Ok(())
@@ -270,8 +296,11 @@ impl Wast {
             err
         };
 
-        let buf = wast::parser::ParseBuffer::new(wast).map_err(adjust_wast)?;
-        let ast = wast::parser::parse::<wast::Wast>(&buf).map_err(adjust_wast)?;
+        let mut lexer = Lexer::new(wast);
+        lexer.allow_confusing_unicode(filename.ends_with("names.wast"));
+        let buf = wast::parser::ParseBuffer::new_with_lexer(lexer).map_err(adjust_wast)?;
+        let ast = parser::parse::<WWast>(&buf).map_err(adjust_wast)?;
+
         let mut errors = Vec::with_capacity(ast.directives.len());
         for directive in ast.directives {
             let sp = directive.span();
@@ -307,28 +336,28 @@ impl Wast {
         Ok(())
     }
 
-    fn parse_quote_module(&self, test: &Path, source: &[&[u8]]) -> Result<Vec<u8>> {
-        let mut ret = String::new();
-        for src in source {
-            match str::from_utf8(src) {
-                Ok(s) => ret.push_str(s),
-                Err(_) => bail!("malformed UTF-8 encoding"),
-            }
-            ret.push(' ');
-        }
-        let buf = wast::parser::ParseBuffer::new(&ret)?;
-        let mut wat = wast::parser::parse::<wast::Wat>(&buf)?;
+    //fn parse_quote_module(&self, test: &Path, source: &[&[u8]]) -> Result<Vec<u8>> {
+    //    let mut ret = String::new();
+    //    for src in source {
+    //        match str::from_utf8(src) {
+    //            Ok(s) => ret.push_str(s),
+    //            Err(_) => bail!("malformed UTF-8 encoding"),
+    //        }
+    //        ret.push(' ');
+    //    }
+    //    let buf = wast::parser::ParseBuffer::new(&ret)?;
+    //    let mut wat = wast::parser::parse::<wast::Wat>(&buf)?;
 
-        // TODO: when memory64 merges into the proper spec then this should be
-        // removed since it will presumably no longer be a text-format error but
-        // rather a validation error. Currently all non-memory64 proposals
-        // assert that this offset is a text-parser error, whereas with memory64
-        // support that error is deferred until later.
-        if ret.contains("offset=4294967296") && !test.iter().any(|t| t == "memory64") {
-            bail!("i32 constant out of bounds");
-        }
-        Ok(wat.module.encode()?)
-    }
+    //    // TODO: when memory64 merges into the proper spec then this should be
+    //    // removed since it will presumably no longer be a text-format error but
+    //    // rather a validation error. Currently all non-memory64 proposals
+    //    // assert that this offset is a text-parser error, whereas with memory64
+    //    // support that error is deferred until later.
+    //    if ret.contains("offset=4294967296") && !test.iter().any(|t| t == "memory64") {
+    //        bail!("i32 constant out of bounds");
+    //    }
+    //    Ok(wat.encode()?)
+    //}
 
     /// Run a wast script from a file.
     pub fn run_file(&mut self, path: &Path) -> Result<()> {
@@ -416,20 +445,23 @@ impl Wast {
     }
 
     /// Translate from a `script::Value` to a `Value`.
-    fn runtime_value(&mut self, v: &wast::Expression<'_>) -> Result<Value> {
-        use wast::Instruction::*;
+    fn runtime_value(&mut self, v: &WastArgCore) -> Result<Value> {
+        use wast::core::WastArgCore::*;
 
-        if v.instrs.len() != 1 {
-            bail!("too many instructions in {:?}", v);
-        }
-        Ok(match &v.instrs[0] {
-            I32Const(x) => Value::I32(*x),
-            I64Const(x) => Value::I64(*x),
-            F32Const(x) => Value::F32(f32::from_bits(x.bits)),
-            F64Const(x) => Value::F64(f64::from_bits(x.bits)),
-            V128Const(x) => Value::V128(u128::from_le_bytes(x.to_le_bytes())),
-            RefNull(wast::HeapType::Func) => Value::FuncRef(None),
-            RefNull(wast::HeapType::Extern) => Value::null(),
+        Ok(match v {
+            I32(x) => Value::I32(*x),
+            I64(x) => Value::I64(*x),
+            F32(x) => Value::F32(f32::from_bits(x.bits)),
+            F64(x) => Value::F64(f64::from_bits(x.bits)),
+            V128(x) => Value::V128(u128::from_le_bytes(x.to_le_bytes())),
+            RefNull(HeapType::Abstract {
+                ty: AbstractHeapType::Func,
+                ..
+            }) => Value::FuncRef(None),
+            RefNull(HeapType::Abstract {
+                ty: AbstractHeapType::Extern,
+                ..
+            }) => Value::null(),
             RefExtern(number) => Value::ExternRef(Some(ExternRef::new(&mut self.store, *number))),
             other => bail!("couldn't convert {:?} to a runtime value", other),
         })
@@ -456,6 +488,16 @@ impl Wast {
             // handle `unknown memory $NUM` error messages that wasmparser doesn't return yet
             || (expected.contains("unknown memory") && actual.contains("unknown memory"))
             || (expected.contains("unknown memory") && actual.contains("Data segment extends past end of the data section"))
+            || (expected.contains("unknown elem segment") && actual.contains("unknown element segment"))
+            // The same test here is asserted to have one error message in
+            // `memory.wast` and a different error message in
+            // `memory64/memory.wast`, so we equate these two error messages to get
+            // the memory64 tests to pass.
+            || (expected.contains("memory size must be at most 65536 pages") && actual.contains("invalid u32 number"))
+            // the spec test suite asserts a different error message than we print
+            // for this scenario
+            || (expected == "unknown global" && actual.contains("global.get of locally defined global"))
+            || (expected == "immutable global" && actual.contains("global is immutable: cannot modify it with `global.set`"))
     }
 
     // Checks if the `assert_trap` message matches the expected one
@@ -467,30 +509,38 @@ impl Wast {
                 .map_or(false, |alternative| actual.contains(alternative))
     }
 
-    fn val_matches(&self, actual: &Value, expected: &wast::AssertExpression) -> Result<bool> {
+    fn val_matches(&self, actual: &Value, expected: &WastRetCore) -> Result<bool> {
         Ok(match (actual, expected) {
-            (Value::I32(a), wast::AssertExpression::I32(b)) => a == b,
-            (Value::I64(a), wast::AssertExpression::I64(b)) => a == b,
+            (Value::I32(a), WastRetCore::I32(b)) => a == b,
+            (Value::I64(a), WastRetCore::I64(b)) => a == b,
             // Note that these float comparisons are comparing bits, not float
             // values, so we're testing for bit-for-bit equivalence
-            (Value::F32(a), wast::AssertExpression::F32(b)) => f32_matches(*a, b),
-            (Value::F64(a), wast::AssertExpression::F64(b)) => f64_matches(*a, b),
-            (Value::V128(a), wast::AssertExpression::V128(b)) => v128_matches(*a, b),
-            (Value::FuncRef(None), wast::AssertExpression::RefNull(Some(wast::HeapType::Func))) => {
-                true
-            }
-            (Value::FuncRef(Some(_)), wast::AssertExpression::RefNull(_)) => false,
-            (Value::FuncRef(None), wast::AssertExpression::RefFunc(None)) => true,
-            (Value::FuncRef(None), wast::AssertExpression::RefFunc(Some(_))) => false,
+            (Value::F32(a), WastRetCore::F32(b)) => f32_matches(*a, b),
+            (Value::F64(a), WastRetCore::F64(b)) => f64_matches(*a, b),
+            (Value::V128(a), WastRetCore::V128(b)) => v128_matches(*a, b),
+            (
+                Value::FuncRef(None),
+                WastRetCore::RefNull(Some(wast::core::HeapType::Abstract {
+                    ty: AbstractHeapType::Func,
+                    ..
+                })),
+            ) => true,
+            (Value::FuncRef(Some(_)), WastRetCore::RefNull(_)) => false,
+            (Value::FuncRef(None), WastRetCore::RefFunc(None)) => true,
+            (Value::FuncRef(None), WastRetCore::RefFunc(Some(_))) => false,
             (
                 Value::ExternRef(None),
-                wast::AssertExpression::RefNull(Some(wast::HeapType::Extern)),
+                WastRetCore::RefNull(Some(wast::core::HeapType::Abstract {
+                    ty: AbstractHeapType::Extern,
+                    ..
+                })),
             ) => true,
-            (Value::ExternRef(None), wast::AssertExpression::RefExtern(_)) => false,
+            (Value::ExternRef(None), WastRetCore::RefExtern(_)) => false,
 
-            (Value::ExternRef(Some(_)), wast::AssertExpression::RefNull(_)) => false,
-            (Value::ExternRef(Some(extern_ref)), wast::AssertExpression::RefExtern(num)) => {
-                extern_ref.downcast(&self.store) == Some(num)
+            (Value::ExternRef(Some(_)), WastRetCore::RefNull(_)) => false,
+            (Value::ExternRef(Some(extern_ref)), WastRetCore::RefExtern(num)) => {
+                let x = extern_ref.downcast::<u32>(&self.store).cloned();
+                x == *num
             }
             _ => bail!(
                 "don't know how to compare {:?} and {:?} yet",
@@ -517,54 +567,54 @@ fn extract_lane_as_i64(bytes: u128, lane: usize) -> i64 {
     (bytes >> (lane * 64)) as i64
 }
 
-fn f32_matches(actual: f32, expected: &wast::NanPattern<wast::Float32>) -> bool {
+fn f32_matches(actual: f32, expected: &wast::core::NanPattern<F32>) -> bool {
     match expected {
-        wast::NanPattern::CanonicalNan => actual.is_canonical_nan(),
-        wast::NanPattern::ArithmeticNan => actual.is_arithmetic_nan(),
-        wast::NanPattern::Value(expected_value) => actual.to_bits() == expected_value.bits,
+        wast::core::NanPattern::CanonicalNan => actual.is_canonical_nan(),
+        wast::core::NanPattern::ArithmeticNan => actual.is_arithmetic_nan(),
+        wast::core::NanPattern::Value(expected_value) => actual.to_bits() == expected_value.bits,
     }
 }
 
-fn f64_matches(actual: f64, expected: &wast::NanPattern<wast::Float64>) -> bool {
+fn f64_matches(actual: f64, expected: &wast::core::NanPattern<F64>) -> bool {
     match expected {
-        wast::NanPattern::CanonicalNan => actual.is_canonical_nan(),
-        wast::NanPattern::ArithmeticNan => actual.is_arithmetic_nan(),
-        wast::NanPattern::Value(expected_value) => actual.to_bits() == expected_value.bits,
+        wast::core::NanPattern::CanonicalNan => actual.is_canonical_nan(),
+        wast::core::NanPattern::ArithmeticNan => actual.is_arithmetic_nan(),
+        wast::core::NanPattern::Value(expected_value) => actual.to_bits() == expected_value.bits,
     }
 }
 
-fn v128_matches(actual: u128, expected: &wast::V128Pattern) -> bool {
+fn v128_matches(actual: u128, expected: &wast::core::V128Pattern) -> bool {
     match expected {
-        wast::V128Pattern::I8x16(b) => b
+        wast::core::V128Pattern::I8x16(b) => b
             .iter()
             .enumerate()
             .all(|(i, b)| *b == extract_lane_as_i8(actual, i)),
-        wast::V128Pattern::I16x8(b) => b
+        wast::core::V128Pattern::I16x8(b) => b
             .iter()
             .enumerate()
             .all(|(i, b)| *b == extract_lane_as_i16(actual, i)),
-        wast::V128Pattern::I32x4(b) => b
+        wast::core::V128Pattern::I32x4(b) => b
             .iter()
             .enumerate()
             .all(|(i, b)| *b == extract_lane_as_i32(actual, i)),
-        wast::V128Pattern::I64x2(b) => b
+        wast::core::V128Pattern::I64x2(b) => b
             .iter()
             .enumerate()
             .all(|(i, b)| *b == extract_lane_as_i64(actual, i)),
-        wast::V128Pattern::F32x4(b) => b.iter().enumerate().all(|(i, b)| {
+        wast::core::V128Pattern::F32x4(b) => b.iter().enumerate().all(|(i, b)| {
             let a = extract_lane_as_i32(actual, i) as u32;
             f32_matches(f32::from_bits(a), b)
         }),
-        wast::V128Pattern::F64x2(b) => b.iter().enumerate().all(|(i, b)| {
+        wast::core::V128Pattern::F64x2(b) => b.iter().enumerate().all(|(i, b)| {
             let a = extract_lane_as_i64(actual, i) as u64;
             f64_matches(f64::from_bits(a), b)
         }),
     }
 }
 
-fn v128_format(actual: u128, expected: &wast::V128Pattern) -> wast::V128Pattern {
+fn v128_format(actual: u128, expected: &wast::core::V128Pattern) -> wast::core::V128Pattern {
     match expected {
-        wast::V128Pattern::I8x16(_) => wast::V128Pattern::I8x16([
+        wast::core::V128Pattern::I8x16(_) => wast::core::V128Pattern::I8x16([
             extract_lane_as_i8(actual, 0),
             extract_lane_as_i8(actual, 1),
             extract_lane_as_i8(actual, 2),
@@ -582,7 +632,7 @@ fn v128_format(actual: u128, expected: &wast::V128Pattern) -> wast::V128Pattern
             extract_lane_as_i8(actual, 14),
             extract_lane_as_i8(actual, 15),
         ]),
-        wast::V128Pattern::I16x8(_) => wast::V128Pattern::I16x8([
+        wast::core::V128Pattern::I16x8(_) => wast::core::V128Pattern::I16x8([
             extract_lane_as_i16(actual, 0),
             extract_lane_as_i16(actual, 1),
             extract_lane_as_i16(actual, 2),
@@ -592,35 +642,35 @@ fn v128_format(actual: u128, expected: &wast::V128Pattern) -> wast::V128Pattern
             extract_lane_as_i16(actual, 6),
             extract_lane_as_i16(actual, 7),
         ]),
-        wast::V128Pattern::I32x4(_) => wast::V128Pattern::I32x4([
+        wast::core::V128Pattern::I32x4(_) => wast::core::V128Pattern::I32x4([
             extract_lane_as_i32(actual, 0),
             extract_lane_as_i32(actual, 1),
             extract_lane_as_i32(actual, 2),
             extract_lane_as_i32(actual, 3),
         ]),
-        wast::V128Pattern::I64x2(_) => wast::V128Pattern::I64x2([
+        wast::core::V128Pattern::I64x2(_) => wast::core::V128Pattern::I64x2([
             extract_lane_as_i64(actual, 0),
             extract_lane_as_i64(actual, 1),
         ]),
-        wast::V128Pattern::F32x4(_) => wast::V128Pattern::F32x4([
-            wast::NanPattern::Value(wast::Float32 {
+        wast::core::V128Pattern::F32x4(_) => wast::core::V128Pattern::F32x4([
+            wast::core::NanPattern::Value(F32 {
                 bits: extract_lane_as_i32(actual, 0) as _,
             }),
-            wast::NanPattern::Value(wast::Float32 {
+            wast::core::NanPattern::Value(F32 {
                 bits: extract_lane_as_i32(actual, 1) as _,
             }),
-            wast::NanPattern::Value(wast::Float32 {
+            wast::core::NanPattern::Value(F32 {
                 bits: extract_lane_as_i32(actual, 2) as _,
             }),
-            wast::NanPattern::Value(wast::Float32 {
+            wast::core::NanPattern::Value(F32 {
                 bits: extract_lane_as_i32(actual, 3) as _,
             }),
         ]),
-        wast::V128Pattern::F64x2(_) => wast::V128Pattern::F64x2([
-            wast::NanPattern::Value(wast::Float64 {
+        wast::core::V128Pattern::F64x2(_) => wast::core::V128Pattern::F64x2([
+            wast::core::NanPattern::Value(F64 {
                 bits: extract_lane_as_i64(actual, 0) as _,
             }),
-            wast::NanPattern::Value(wast::Float64 {
+            wast::core::NanPattern::Value(F64 {
                 bits: extract_lane_as_i64(actual, 1) as _,
             }),
         ]),
