@@ -3,7 +3,7 @@ use indicatif::ProgressBar;
 use std::{fs::File, io::BufReader, path::Path, process::Command, sync::Arc};
 use tokio::time::{self, Instant};
 use tracing::*;
-use wasmer_api::types::PackageVersionWithPackage;
+use wasmer_backend_api::types::PackageVersionWithPackage;
 use webc::{v2::read::OwnedReader, v3::read::OwnedReader as OwnedReaderV3, Container, Version};
 
 use super::{TestReport, Tester};
@@ -55,33 +55,33 @@ impl<'a> CLIRunner<'a> {
             Backend::Cranelift => "--cranelift",
         };
 
-        Ok(
-            match std::panic::catch_unwind(move || {
-                let mut cmd = Command::new(cli_path);
+        let res = std::panic::catch_unwind(move || {
+            let mut cmd = Command::new(cli_path);
 
-                let cmd = cmd.args([
-                    "compile",
-                    atom_path.to_str().unwrap(),
-                    backend,
-                    "-o",
-                    output_path.to_str().unwrap(),
-                ]);
+            let cmd = cmd.args([
+                "compile",
+                atom_path.to_str().unwrap(),
+                backend,
+                "-o",
+                output_path.to_str().unwrap(),
+            ]);
 
-                info!("running cmd: {:?}", cmd);
+            info!("running cmd: {:?}", cmd);
 
-                let out = cmd.output();
+            let out = cmd.output();
 
-                info!("run cmd that gave result: {:#?}", out);
+            info!("run cmd that gave result: {:#?}", out);
 
-                out
-            }) {
-                Ok(r) => match r {
-                    Ok(_) => Ok(()),
-                    Err(e) => Err(e.to_string()),
-                },
-                Err(_) => Err(String::from("thread panicked")),
+            out
+        });
+
+        Ok(match res {
+            Ok(r) => match r {
+                Ok(_) => Ok(()),
+                Err(e) => Err(e.to_string()),
             },
-        )
+            Err(_) => Err(String::from("thread panicked")),
+        })
     }
 
     fn ok(&self, version: String, start_time: Instant) -> anyhow::Result<TestReport> {
